@@ -26,6 +26,8 @@ import org.eclipse.ui.actions.ActionFactory.IWorkbenchAction;
 import org.eclipse.ui.application.ActionBarAdvisor;
 import org.eclipse.ui.application.IActionBarConfigurer;
 
+import com.clustercontrol.util.Messages;
+
 /**
  * ActionBarAdvisorクラスを継承するクラス<BR>
  * RCPのActionBarの設定などを行うクラス
@@ -56,10 +58,10 @@ public class ClusterControlActionBarAdvisor extends ActionBarAdvisor {
 	@Override
 	protected void fillMenuBar(IMenuManager menuBar) {
 		//ヘルプメニューを追加
-		MenuManager helpMenu = new MenuManager(JFaceResources.getString("help"),
+		MenuManager helpMenu = new MenuManager(Messages.getString("help"),
 				IWorkbenchActionConstants.M_HELP);
 		//製品情報用ヘルプメニューを追加
-		MenuManager aboutMenu = new MenuManager(JFaceResources.getString("help"),
+		MenuManager aboutMenu = new MenuManager(Messages.getString("help"),
 				IWorkbenchActionConstants.M_HELP + "_about");
 
 		menuBar.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
