@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2006 NTT DATA Corporation
+Copyright (C) 2013 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
@@ -18,13 +18,15 @@ package com.clustercontrol;
 import org.eclipse.ui.IPageLayout;
 import org.eclipse.ui.IPerspectiveFactory;
 
+import com.clustercontrol.plugin.menu.LoadMenuPlugin;
+
 /**
  * 基底パースペクティブ<BR>
  * 
  * パースペクティブはこのクラスを継承すること。
  * 
  * 
- * @version 1.0.1
+ * @version 4.1.0
  * @since 1.0.0
  */
 public class ClusterControlPerspectiveBase implements IPerspectiveFactory{
@@ -36,6 +38,7 @@ public class ClusterControlPerspectiveBase implements IPerspectiveFactory{
 	 */
 	@Override
 	public void createInitialLayout(IPageLayout layout) {
+
 		//エディタを非表示
 		layout.setEditorAreaVisible(false);
 
@@ -49,11 +52,17 @@ public class ClusterControlPerspectiveBase implements IPerspectiveFactory{
 		layout.addActionSet("com.clustercontrol.monitor.run.ActionSet");
 		layout.addActionSet("com.clustercontrol.jobmanagement.ActionSet");
 		layout.addActionSet("com.clustercontrol.performance.ActionSet");
-		layout.addActionSet("com.clustercontrol.performance.ActionSet");
+		layout.addActionSet("com.clustercontrol.accesscontrol.ActionSet");
+
 		layout.addActionSet("com.clustercontrol.vm.ActionSet");
 		layout.addActionSet("com.clustercontrol.nodemap.ActionSet");
 		layout.addActionSet("com.clustercontrol.jobmap.ActionSet");
 		layout.addActionSet("com.clustercontrol.openflow.ActionSet");
 		layout.addActionSet("com.clustercontrol.utilityoption.ActionSet");
+		
+		//menu 追加用
+		for(String actionSetId: LoadMenuPlugin.getExtensionMenuList()){
+			layout.addActionSet(actionSetId);
+		}
 	}
 }
\ No newline at end of file
