@@ -24,7 +24,7 @@ import com.clustercontrol.jobmanagement.bean.JobConstant;
 /**
  * ジョブイメージ定数のクラス<BR>
  * 
- * @version 2.0.0
+ * @version 4.1.0
  * @since 1.0.0
  */
 public class JobImageConstant extends JobConstant {
@@ -38,6 +38,8 @@ public class JobImageConstant extends JobConstant {
 
 	private static Image fileJob = null;
 
+	private static Image referJob = null;
+
 	/**
 	 * 種別からImageに変換します。<BR>
 	 * 
@@ -46,7 +48,7 @@ public class JobImageConstant extends JobConstant {
 	 */
 	public static Image typeToImage(int type) {
 		ImageRegistry registry = ClusterControlPlugin.getDefault()
-		.getImageRegistry();
+				.getImageRegistry();
 
 		if (type == TYPE_JOBUNIT || type == TYPE_COMPOSITE) {
 			if (jobUnit == null)
@@ -73,6 +75,11 @@ public class JobImageConstant extends JobConstant {
 				fileJob = registry.getDescriptor(
 						ClusterControlPlugin.IMG_FILEJOB).createImage();
 			return fileJob;
+		} else if (type == TYPE_REFERJOB) {
+			if (referJob == null)
+				referJob = registry.getDescriptor(
+						ClusterControlPlugin.IMG_REFERJOB).createImage();
+			return referJob;
 		}
 
 		return null;
