@@ -178,8 +178,11 @@ public class CommonDialog extends Dialog {
 
 		if (areaComposite.getSize().x > 0 && areaComposite.getSize().y > 0) {
 			// 各ダイアログ側でpackがされている場合
-			scrolledComposite.setMinSize(areaComposite.getSize().x,
-					areaComposite.getSize().y);
+			scrolledComposite.setMinSize(
+					areaComposite.computeSize(SWT.DEFAULT, SWT.DEFAULT));
+			// 縦スクロールバーが表示された場合に、横スクロールバーが表示されてしまうため、
+			// スクロールバーが表示されるサイズからあらかじめ引いておく
+			scrolledComposite.setMinWidth(areaComposite.getSize().x - 20);
 		} else {
 			//各ダイアログ側でpackがされていない場合
 			/*
