@@ -25,6 +25,7 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.composite.FacilityTreeComposite;
+import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
 
@@ -39,15 +40,18 @@ public class ScopeTreeDialog extends CommonDialog {
 	// ----- instance フィールド ----- //
 
 	/** 選択されたアイテム */
-	protected FacilityTreeComposite treeComposite = null;
+	private FacilityTreeComposite treeComposite = null;
 
 	/**ノードをツリーに含めるかのフラグ**/
-	protected boolean scopeOnly;
+	private boolean scopeOnly;
 	/**未登録ノード　スコープを含めるかのフラグ**/
-	protected boolean unregistered;
+	private boolean unregistered;
 
 	/** ノードのみを選択可能とするフラグ **/
-	protected boolean selectNodeOnly;
+	private boolean selectNodeOnly;
+
+	/** オーナーロールID **/
+	private String ownerRoleId = null;
 
 	// ----- コンストラクタ ----- //
 
@@ -55,10 +59,12 @@ public class ScopeTreeDialog extends CommonDialog {
 	 * ダイアログのインスタンスを返します。
 	 * 
 	 * @param parent
+	 * @param ownerRoleId
 	 *            親とするシェル
 	 */
-	public ScopeTreeDialog(Shell parent) {
+	public ScopeTreeDialog(Shell parent, String ownerRoleId) {
 		super(parent);
+		this.ownerRoleId = ownerRoleId;
 		this.scopeOnly = false;
 		//未登録ノードスコープはデフォルト非表示
 		this.unregistered = false;
@@ -72,15 +78,17 @@ public class ScopeTreeDialog extends CommonDialog {
 	 *            親とするシェル
 	 * @param scopeOnly
 	 */
-	public ScopeTreeDialog(Shell parent, boolean scopeOnly) {
+	public ScopeTreeDialog(Shell parent, String ownerRoleId, boolean scopeOnly) {
 		super(parent);
+		this.ownerRoleId = ownerRoleId;
 		this.scopeOnly = scopeOnly;
 		//未登録ノードスコープはデフォルト非表示
 		this.unregistered = false;
 	}
 
-	public ScopeTreeDialog(Shell parent, boolean scopeOnly, boolean unregistered){
+	public ScopeTreeDialog(Shell parent, String ownerRoleId, boolean scopeOnly, boolean unregistered){
 		super(parent);
+		this.ownerRoleId = ownerRoleId;
 		this.scopeOnly = scopeOnly;
 		//未登録ノードスコープはデフォルト非表示
 		this.unregistered = unregistered;
@@ -109,9 +117,9 @@ public class ScopeTreeDialog extends CommonDialog {
 		layout.marginWidth = 0;
 
 		if(selectNodeOnly){
-			treeComposite = new FacilityTreeComposite(parent, SWT.NONE, true);
+			treeComposite = new FacilityTreeComposite(parent, SWT.NONE, this.ownerRoleId, true);
 		}else{
-			treeComposite = new FacilityTreeComposite(parent, SWT.NONE, scopeOnly, unregistered, false);
+			treeComposite = new FacilityTreeComposite(parent, SWT.NONE, this.ownerRoleId, scopeOnly, unregistered, false);
 		}
 
 		GridData gridData = new GridData();
@@ -138,7 +146,40 @@ public class ScopeTreeDialog extends CommonDialog {
 
 	@Override
 	protected ValidateResult validate() {
-		return null;
+		ValidateResult result = null;
+		FacilityTreeItem item = this.getSelectItem();
+
+		if (this.selectNodeOnly) {
+			// ノードのみ選択可能な場合
+			if (item == null
+					|| item.getData().isNotReferFlg()
+					|| item.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE
+					|| item.getData().getFacilityType() == FacilityConstant.TYPE_SCOPE) {
+				// 未選択の場合エラー
+				// 参照不可のスコープを選択した場合はエラー
+				// ルートを選択した場合はエラー
+				// スコープを選択するとエラー
+				result = new ValidateResult();
+				result.setValid(false);
+				result.setID(Messages.getString("message.hinemos.1"));
+				result.setMessage(Messages.getString("message.repository.2"));
+			}
+		} else {
+			// ノード・スコープが選択可能な場合
+			if (item == null
+					|| item.getData().isNotReferFlg()
+					|| item.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE) {
+				// 未選択の場合エラー
+				// 参照不可のスコープを選択した場合はエラー
+				// ルートを選択した場合はエラー
+				result = new ValidateResult();
+				result.setValid(false);
+				result.setID(Messages.getString("message.hinemos.1"));
+				result.setMessage(Messages.getString("message.repository.47"));
+			}
+		}
+
+		return result;
 	}
 
 	@Override
