@@ -71,7 +71,7 @@ public class OpenPerspectiveAction implements IWorkbenchWindowActionDelegate {
 	@Override
 	public void run(IAction action) {
 		IPerspectiveRegistry reg = PlatformUI.getWorkbench()
-		.getPerspectiveRegistry();
+				.getPerspectiveRegistry();
 
 		SelectPerspectiveDialog dlg = new SelectPerspectiveDialog(window
 				.getShell(), reg);
@@ -89,7 +89,7 @@ public class OpenPerspectiveAction implements IWorkbenchWindowActionDelegate {
 	 * 
 	 * @see PerspectiveMenu#run(IPerspectiveDescriptor)
 	 */
-	protected void run(IPerspectiveDescriptor desc) {
+	private void run(IPerspectiveDescriptor desc) {
 		IPreferenceStore store = PlatformUI.getWorkbench().getPreferenceStore();
 		int mode = store.getInt(IPreferenceConstants.OPEN_PERSP_MODE);
 		IWorkbenchPage page = window.getActivePage();
@@ -103,7 +103,7 @@ public class OpenPerspectiveAction implements IWorkbenchWindowActionDelegate {
 			try {
 				IWorkbench workbench = window.getWorkbench();
 				IAdaptable input = ((Workbench) workbench)
-				.getDefaultPageInput();
+						.getDefaultPageInput();
 				workbench.openWorkbenchWindow(desc.getId(), input);
 			} catch (WorkbenchException e) {
 				handleWorkbenchException(e);
@@ -115,7 +115,7 @@ public class OpenPerspectiveAction implements IWorkbenchWindowActionDelegate {
 				try {
 					IWorkbench workbench = window.getWorkbench();
 					IAdaptable input = ((Workbench) workbench)
-					.getDefaultPageInput();
+							.getDefaultPageInput();
 					window.openPage(desc.getId(), input);
 				} catch (WorkbenchException e) {
 					handleWorkbenchException(e);
