@@ -16,6 +16,8 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.accesscontrol.dialog;
 
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.ModifyEvent;
+import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.layout.RowData;
 import org.eclipse.swt.layout.RowLayout;
 import org.eclipse.swt.widgets.Composite;
@@ -25,8 +27,9 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
+import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
-import com.clustercontrol.composite.StringVerifyListener;
+import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
@@ -39,17 +42,17 @@ import com.clustercontrol.util.Messages;
  */
 public class ModifyPasswordDialog extends CommonDialog {
 	/** ユーザID用テキスト */
-	protected Text m_uidText = null;
+	private Text m_uidText = null;
 	/** パスワード用テキスト */
-	protected Text m_passwordText1 = null;
+	private Text m_passwordText1 = null;
 	/** パスワード確認用テキスト */
-	protected Text m_passwordText2 = null;
+	private Text m_passwordText2 = null;
 	/** ユーザID */
-	protected String m_uid = null;
+	private String m_uid = null;
 	/** パスワード */
-	protected String m_password = null;
+	private String m_password = null;
 	/** シェル */
-	protected Shell m_shell = null;
+	private Shell m_shell = null;
 
 	/**
 	 * コンストラクタ
@@ -99,6 +102,7 @@ public class ModifyPasswordDialog extends CommonDialog {
 		m_uidText = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
 		m_uidText.setLayoutData(new RowData(150, SizeConstant.SIZE_TEXT_HEIGHT));
 		m_uidText.setText(m_uid);
+		m_uidText.setEnabled(false);
 
 		composite = new Composite(parent, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -113,6 +117,13 @@ public class ModifyPasswordDialog extends CommonDialog {
 		m_passwordText1.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_64));
 
+		m_passwordText1.addModifyListener(new ModifyListener() {
+			@Override
+			public void modifyText(ModifyEvent e) {
+				update();
+			}
+		});
+
 		composite = new Composite(parent, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -126,6 +137,13 @@ public class ModifyPasswordDialog extends CommonDialog {
 		m_passwordText2.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_64));
 
+		m_passwordText2.addModifyListener(new ModifyListener() {
+			@Override
+			public void modifyText(ModifyEvent e) {
+				update();
+			}
+		});
+
 		new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
 
 		// 画面中央に
@@ -133,7 +151,22 @@ public class ModifyPasswordDialog extends CommonDialog {
 		m_shell.setLocation(
 				(display.getBounds().width - m_shell.getSize().x) / 2, (display
 						.getBounds().height - m_shell.getSize().y) / 2);
-
+		
+		update();
+	}
+	
+	
+	private void update(){
+		if("".equals(this.m_passwordText1.getText())){
+			this.m_passwordText1.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_passwordText1.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+		if("".equals(this.m_passwordText2.getText())){
+			this.m_passwordText2.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_passwordText2.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
 	}
 
 	/**
