@@ -520,7 +520,12 @@ public class Agent {
 		RunHistoryUtil.logHistory();
 
 		try {
-			AgentEndPointWrapper.deleteAgent();
+			// deleteAgentを行った直後に別スレッドのgetTopicと競合するとエージェントが重複した
+			// と認識されるため、deleteAgentとgetoTopicを排他する
+			synchronized(ReceiveTopic.lockTopicReceiveTiming) {
+				AgentEndPointWrapper.deleteAgent();
+				ReceiveTopic.terminate();
+			}
 		} catch (InvalidRole_Exception e) {
 			m_log.info("InvalidRoleException " + e.getMessage());
 		} catch (InvalidUserPass_Exception e) {
@@ -711,59 +716,60 @@ public class Agent {
 	}
 
 	public static AgentInfo getAgentInfo() {
-		// IPアドレスが変更されて設定の再取得中はagentInfoを書き換えない
-		if (ReceiveTopic.isReloadFlg()) {
-			return agentInfo;
-		}
-
+		
+		// OS情報以外の情報は、毎回セットする
 		agentInfo.setFacilityId(AgentProperties.getProperty("facilityId"));
-
+		
+		if (m_receiveTopic != null) {
+			agentInfo.setInterval(m_receiveTopic.getTopicInterval());
+		}
+		
 		// OS情報(識別したホスト名、IPアドレス)
-		try {
-			// ホスト名取得
-			String hostname = System.getProperty("hostname");
-			m_log.debug("hostname=[" + hostname + "]");
-			agentInfo.setHostname(hostname);
-
-			// IPアドレス取得
-			Enumeration<NetworkInterface> networkInterfaces = NetworkInterface.getNetworkInterfaces();
-			String newIpAddressStr = "";
-			ArrayList<String> newIpAddressList = new ArrayList<String>();
-			if (null != networkInterfaces) {
-				while (networkInterfaces.hasMoreElements()) {
-					NetworkInterface ni = networkInterfaces.nextElement();
-					Enumeration<InetAddress> inetAddresses = ni.getInetAddresses();
-					while (inetAddresses.hasMoreElements()) {
-						InetAddress in = inetAddresses.nextElement();
-						String hostAddress = in.getHostAddress();
-						if (hostAddress != null && !hostAddress.equals("127.0.0.1") &&
-								!hostAddress.startsWith("0:0:0:0:0:0:0:1") &&
-								!hostAddress.equals("::1")) {
-							newIpAddressList.add(hostAddress);
-							newIpAddressStr += "," + hostAddress;
+		// IPアドレスが変更されて設定の再取得中はagentInfo内のOS情報を書き換えない
+		if (!ReceiveTopic.isReloadFlg()) {
+			try {
+				// ホスト名取得
+				String hostname = System.getProperty("hostname");
+				m_log.debug("hostname=[" + hostname + "]");
+				agentInfo.setHostname(hostname);
+	
+				// IPアドレス取得
+				Enumeration<NetworkInterface> networkInterfaces = NetworkInterface.getNetworkInterfaces();
+				String newIpAddressStr = "";
+				ArrayList<String> newIpAddressList = new ArrayList<String>();
+				if (null != networkInterfaces) {
+					while (networkInterfaces.hasMoreElements()) {
+						NetworkInterface ni = networkInterfaces.nextElement();
+						Enumeration<InetAddress> inetAddresses = ni.getInetAddresses();
+						while (inetAddresses.hasMoreElements()) {
+							InetAddress in = inetAddresses.nextElement();
+							String hostAddress = in.getHostAddress();
+							if (hostAddress != null && !hostAddress.equals("127.0.0.1") &&
+									!hostAddress.startsWith("0:0:0:0:0:0:0:1") &&
+									!hostAddress.equals("::1")) {
+								newIpAddressList.add(hostAddress);
+								newIpAddressStr += "," + hostAddress;
+							}
 						}
 					}
 				}
-			}
-			if (agentInfo.getIpAddress().size() != newIpAddressList.size()) {
-				m_log.info("ipAddress change : " + agentInfo.getIpAddress().size() +
-						"," + newIpAddressList.size());
-				agentInfo.getIpAddress().clear();
-				agentInfo.getIpAddress().addAll(newIpAddressList);
-				ReceiveTopic.setReloadFlg(true);
-			} else {
-				if (!agentInfo.getIpAddress().containsAll(newIpAddressList)) {
-					m_log.info("ipAddress change");
+				if (agentInfo.getIpAddress().size() != newIpAddressList.size()) {
+					m_log.info("ipAddress change : " + agentInfo.getIpAddress().size() +
+							"," + newIpAddressList.size());
 					agentInfo.getIpAddress().clear();
 					agentInfo.getIpAddress().addAll(newIpAddressList);
 					ReceiveTopic.setReloadFlg(true);
+				} else {
+					if (!agentInfo.getIpAddress().containsAll(newIpAddressList)) {
+						m_log.info("ipAddress change");
+						agentInfo.getIpAddress().clear();
+						agentInfo.getIpAddress().addAll(newIpAddressList);
+						ReceiveTopic.setReloadFlg(true);
+					}
 				}
+			} catch (SocketException e) {
+				m_log.error(e,e);
 			}
-		} catch (SocketException e) {
-			m_log.error(e,e);
-		}
-		if (m_receiveTopic != null) {
-			agentInfo.setInterval(m_receiveTopic.getTopicInterval());
 		}
 		m_log.debug(getAgentStr());
 
