@@ -16,11 +16,7 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.agent;
 
 import java.util.concurrent.Callable;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
-import java.util.concurrent.Future;
 import java.util.concurrent.ThreadFactory;
-import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -42,8 +38,6 @@ public class SendQueue {
 	//ロガー
 	static private Log m_log = LogFactory.getLog(SendQueue.class);
 
-	private static final long SEND_TIMEOUT = 60 * 1000l;
-
 	private long m_sendQueueReconnectionInterval = 10 * 1000l;
 
 	/**
@@ -68,39 +62,20 @@ public class SendQueue {
 			m_log.debug("put() while (!ReceiveTopic.isHistoryClear()) is true");
 
 			boolean sendQueueStatus = false;
-			ExecutorService es = null;
-			Future<Boolean> task = null;
 			try {
-				String id = "";
-				// Executorオブジェクトの生成
-				SenderThreadFactory threadFactory = new SenderThreadFactory(id);
-				es = Executors.newSingleThreadExecutor(threadFactory);
-
 				// Queue送信タスクを実行する。
-				// 別スレッドでQueue送信処理を実行することで、送信処理に無限の時間がかかっても、
-				// Future.get()のタイムアウトにより、本スレッドに制御が戻るようにする。
-				m_log.debug("put() submit");
-				task = es.submit(new Sender(info));
-				sendQueueStatus = task.get(SEND_TIMEOUT, TimeUnit.MILLISECONDS);
+				// タイムアウトはAgent自体の機構でカバーできるため、ここでは意識しない
+				m_log.debug("put() call");
+				sendQueueStatus = new Sender(info).call();
 
 			} catch (Exception e) {
-				// Queue送信処理で例外が発生した場合、もしくは、Future.get()でタイムアウトが発生した場合に、
+				// Queue送信処理で例外が発生した場合
 				// ここに制御が移る
 
 				// ログファイルにログ出力
 				m_log.warn("put() : Failed to connect to MGR " + e.getMessage(), e);
 
-			} finally {
-				// タスクをキャンセル
-				if (task != null) {
-					task.cancel(true);
-				}
-
-				if (es != null) {
-					es.shutdown();
-				}
-				m_log.debug("put() end    : " + info.getClass().getCanonicalName());
-			}
+			} 
 
 			// 送信が成功していない場合はsleep後に再送を試みる
 			// Queue送信に成功した場合はループを抜ける
