@@ -121,18 +121,14 @@ public class CalPatternInfoEntity extends ObjectPrivilegeTargetEntity {
 	 * 
 	 */
 	public void deleteCalPatternDetailInfoEntities(List<CalPatternDetailInfoEntityPK> notDelPkList) {
-		if (notDelPkList == null || notDelPkList.size() == 0) {
-			this.setCalPatternDetailInfoEntities(null);
-		} else {
-			EntityManager em = new JpaTransactionManager().getEntityManager();
-			List<CalPatternDetailInfoEntity> list = this.getCalPatternDetailInfoEntities();
-			Iterator<CalPatternDetailInfoEntity> iter = list.iterator();
-			while(iter.hasNext()) {
-				CalPatternDetailInfoEntity entity = iter.next();
-				if (!notDelPkList.contains(entity.getId())) {
-					iter.remove();
-					em.remove(entity);
-				}
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+		List<CalPatternDetailInfoEntity> list = this.getCalPatternDetailInfoEntities();
+		Iterator<CalPatternDetailInfoEntity> iter = list.iterator();
+		while(iter.hasNext()) {
+			CalPatternDetailInfoEntity entity = iter.next();
+			if (!notDelPkList.contains(entity.getId())) {
+				iter.remove();
+				em.remove(entity);
 			}
 		}
 	}
