@@ -33,7 +33,7 @@ import com.clustercontrol.collectiverun.action.ModifyMaster;
 import com.clustercontrol.collectiverun.bean.ParameterTypeConstant;
 import com.clustercontrol.collectiverun.composite.action.MasterInfoModifyListener;
 import com.clustercontrol.collectiverun.util.TreeItemUtil;
-import com.clustercontrol.composite.StringVerifyListener;
+import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.collectiverun.ItemInfo;
@@ -429,7 +429,7 @@ public class ParameterComposite extends Composite {
 	 * @param result
 	 *            ValidateResultオブジェクト
 	 */
-	protected void displayError(ValidateResult result) {
+	private void displayError(ValidateResult result) {
 		MessageDialog.openWarning(
 				null,
 				result.getID(),
