@@ -37,6 +37,9 @@ import com.clustercontrol.collectiverun.composite.action.DeleteTreeItemSelection
 import com.clustercontrol.collectiverun.composite.action.UpDownTreeItemSelectionListener;
 import com.clustercontrol.collectiverun.composite.action.UpdateTreeItemSelectionListener;
 import com.clustercontrol.collectiverun.util.CollectiveRunEndpointWrapper;
+import com.clustercontrol.collectiverun.viewer.TreeContentProvider;
+import com.clustercontrol.collectiverun.viewer.TreeLabelProvider;
+import com.clustercontrol.collectiverun.viewer.TreeViewerSorter;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.collectiverun.InvalidRole_Exception;
 import com.clustercontrol.ws.collectiverun.ItemInfo;
@@ -198,7 +201,7 @@ public class TreeComposite extends Composite {
 	 * ポップアップメニュー作成
 	 * 
 	 */
-	protected void createContextMenu() {
+	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
 		menuManager.addMenuListener(new IMenuListener() {
@@ -223,7 +226,7 @@ public class TreeComposite extends Composite {
 	 * 
 	 * @param manager
 	 */
-	protected void fillContextMenu(IMenuManager manager) {
+	private void fillContextMenu(IMenuManager manager) {
 		//ポップアップメニューにアクションを追加
 		CopyTreeItemAction copyAction = new CopyTreeItemAction(this);
 		manager.add(copyAction);
