@@ -34,7 +34,7 @@ import com.clustercontrol.ws.collectiverun.TreeItem;
  * @since 2.1.0
  */
 public class UpDownTreeItemSelectionListener extends BaseTreeItemSelectionListener {
-	protected boolean up;
+	private boolean up;
 
 	/**
 	 * コンストラクタ
