@@ -45,14 +45,16 @@ public class GetJobTableDefine {
 	public static final int SCOPE = 4;
 	/** 待ち条件 */
 	public static final int WAIT_RULE = 5;
+	/** オーナーロール */
+	public static final int OWNER_ROLE = 6;
 	/** 新規作成ユーザ */
-	public static final int CREATE_USER = 6;
+	public static final int CREATE_USER = 7;
 	/** 作成日時 */
-	public static final int CREATE_TIME = 7;
+	public static final int CREATE_TIME = 8;
 	/** 最終更新ユーザ */
-	public static final int UPDATE_USER = 8;
+	public static final int UPDATE_USER = 9;
 	/** 最終更新日時 */
-	public static final int UPDATE_TIME = 9;
+	public static final int UPDATE_TIME = 10;
 
 	/** 初期表示時ソートカラム */
 	public static final int SORT_COLUMN_INDEX = JOB_ID;
@@ -83,6 +85,8 @@ public class GetJobTableDefine {
 				new TableColumnInfo(Messages.getString("scope", locale), TableColumnInfo.FACILITY, 150, SWT.LEFT));
 		tableDefine.add(WAIT_RULE,
 				new TableColumnInfo(Messages.getString("wait.rule", locale), TableColumnInfo.WAIT_RULE, 80, SWT.LEFT));
+		tableDefine.add(OWNER_ROLE,
+				new TableColumnInfo(Messages.getString("owner.role.id", locale), TableColumnInfo.NONE, 130, SWT.LEFT));
 		tableDefine.add(CREATE_USER,
 				new TableColumnInfo(Messages.getString("creator.name", locale), TableColumnInfo.NONE, 80, SWT.LEFT));
 		tableDefine.add(CREATE_TIME,
