@@ -15,9 +15,6 @@
 
 package com.clustercontrol.jobmanagement.composite;
 
-import java.util.List;
-
-import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
@@ -30,7 +27,6 @@ import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
-import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
@@ -38,13 +34,10 @@ import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.composite.NumberVerifyListener;
+import com.clustercontrol.calendar.composite.CalendarIdListComposite;
+import com.clustercontrol.composite.action.NumberVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
-import com.clustercontrol.jobmanagement.action.GetCalendarIdList;
-import com.clustercontrol.jobmanagement.bean.ConditionTypeConstant;
-import com.clustercontrol.jobmanagement.util.JobEndpointWrapper;
 import com.clustercontrol.util.Messages;
-import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
 
 /**
@@ -55,28 +48,27 @@ import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
  */
 public class ControlComposite extends Composite {
 	/** 保留用チェックボタン */
-	protected Button m_waitCondition = null;
+	private Button m_waitCondition = null;
 	/** スキップ用チェックボタン */
-	protected Button m_skipCondition = null;
+	private Button m_skipCondition = null;
 	/** スキップ用グループ */
-	protected Group m_skipEndConditionGroup = null;
+	private Group m_skipEndConditionGroup = null;
+	/** スキップ終了状態用テキスト */
+	private Combo m_skipEndStatus = null;
 	/** スキップ終了値用テキスト */
-	protected Text m_skipEndValue = null;
+	private Text m_skipEndValue = null;
 	/** カレンダ用チェックボタン */
-	protected Button m_calendarCondition = null;
+	private Button m_calendarCondition = null;
 	/** カレンダ用グループ */
-	protected Group m_calendarConditionGroup = null;
+	private Group m_calendarConditionGroup = null;
 	/** カレンダID用コンボボックス */
-	protected Combo m_calendarId = null;
+	private CalendarIdListComposite m_calendarId = null;
+	/** カレンダ終了状態用テキスト */
+	private Combo m_calendarEndStatus = null;
 	/** カレンダ終了値用テキスト */
-	protected Text m_calendarEndValue = null;
+	private Text m_calendarEndValue = null;
 	/** ジョブ待ち条件情報 */
-	protected JobWaitRuleInfo m_waitRule = null;
-	/** シェル */
-	protected Shell m_shell = null;
-	
-	/* カレンダー参照権限 */
-	private boolean m_calendarReadable = true;
+	private JobWaitRuleInfo m_waitRule = null;
 
 	/**
 	 * コンストラクタ
@@ -91,7 +83,6 @@ public class ControlComposite extends Composite {
 	public ControlComposite(Composite parent, int style) {
 		super(parent, style);
 		initialize();
-		m_shell = this.getShell();
 	}
 
 	/**
@@ -125,11 +116,13 @@ public class ControlComposite extends Composite {
 				Button check = (Button) e.getSource();
 				if (check.getSelection()) {
 					m_calendarConditionGroup.setEnabled(true);
-					m_calendarId.setEnabled(true & m_calendarReadable);
+					m_calendarId.setEnabled(true);
+					m_calendarEndStatus.setEnabled(true);
 					m_calendarEndValue.setEnabled(true);
 				} else {
 					m_calendarConditionGroup.setEnabled(false);
 					m_calendarId.setEnabled(false);
+					m_calendarEndStatus.setEnabled(false);
 					m_calendarEndValue.setEnabled(false);
 				}
 				update();
@@ -159,32 +152,27 @@ public class ControlComposite extends Composite {
 		calendarIdTitle.setText(Messages.getString("calendar.id") + " : ");
 		calendarIdTitle.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_calendarId = new Combo(composite, SWT.LEFT | SWT.READ_ONLY);
-		m_calendarId.setLayoutData(new RowData(100, SizeConstant.SIZE_COMBO_HEIGHT));
-		List<String> idList = null;
-		try {
-			idList = JobEndpointWrapper.getCalendarIdList();
-		} catch (InvalidRole_Exception e) {
-			// アクセス権なしの場合、エラーダイアログを表示する
-			MessageDialog.openInformation(
-					null,
-					Messages.getString("message"),
-					Messages.getString("message.accesscontrol.16"));
-			m_calendarReadable = false;
-			m_calendarId.setEnabled(false);
-		} catch (Exception e) {
-			MessageDialog.openError(
-					null,
-					Messages.getString("failed"),
-					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
-		}
-		if(idList != null){
-			m_calendarId.add("");
-			for(int i = 0; i < idList.size(); i++){
-				m_calendarId.add(idList.get(i));
-			}
-		}
+		m_calendarId = new CalendarIdListComposite(composite, SWT.NONE, false);
+		m_calendarId.setEnabled(false);
 
+		// カレンダ終了状態
+		composite = new Composite(m_calendarConditionGroup, SWT.NONE);
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.spacing = 10;
+		composite.setLayout(rowLayout);
+		Label calendarEndStatusTitle = new Label(composite, SWT.LEFT);
+		calendarEndStatusTitle.setText(Messages.getString("end.status") + " : ");
+		calendarEndStatusTitle.setLayoutData(new RowData(80,
+				SizeConstant.SIZE_LABEL_HEIGHT));
+		m_calendarEndStatus = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_calendarEndStatus.setLayoutData(new RowData(100,
+				SizeConstant.SIZE_COMBO_HEIGHT));
+		m_calendarEndStatus.add(EndStatusConstant.STRING_NORMAL);
+		m_calendarEndStatus.add(EndStatusConstant.STRING_WARNING);
+		m_calendarEndStatus.add(EndStatusConstant.STRING_ABNORMAL);
+
+		// カレンダ終了値
 		composite = new Composite(m_calendarConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -205,7 +193,7 @@ public class ControlComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 
 		//保留
 		composite = new Composite(this, SWT.NONE);
@@ -226,6 +214,7 @@ public class ControlComposite extends Composite {
 				if (check.getSelection()) {
 					m_skipCondition.setSelection(false);
 					m_skipEndConditionGroup.setEnabled(false);
+					m_skipEndStatus.setEnabled(false);
 					m_skipEndValue.setEnabled(false);
 				}
 				update();
@@ -253,10 +242,12 @@ public class ControlComposite extends Composite {
 				Button check = (Button) e.getSource();
 				if (check.getSelection()) {
 					m_skipEndConditionGroup.setEnabled(true);
+					m_skipEndStatus.setEnabled(true);
 					m_skipEndValue.setEnabled(true);
 					m_waitCondition.setSelection(false);
 				} else {
 					m_skipEndConditionGroup.setEnabled(false);
+					m_skipEndStatus.setEnabled(false);
 					m_skipEndValue.setEnabled(false);
 				}
 				update();
@@ -276,6 +267,24 @@ public class ControlComposite extends Composite {
 		rowLayout.spacing = 1;
 		m_skipEndConditionGroup.setLayout(rowLayout);
 
+		// スキップ終了状態
+		composite = new Composite(m_skipEndConditionGroup, SWT.NONE);
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.spacing = 10;
+		composite.setLayout(rowLayout);
+		Label skipEndStatusTitle = new Label(composite, SWT.LEFT);
+		skipEndStatusTitle.setText(Messages.getString("end.status") + " : ");
+		skipEndStatusTitle.setLayoutData(new RowData(80,
+				SizeConstant.SIZE_LABEL_HEIGHT));
+		m_skipEndStatus = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_skipEndStatus.setLayoutData(new RowData(100,
+				SizeConstant.SIZE_COMBO_HEIGHT));
+		m_skipEndStatus.add(EndStatusConstant.STRING_NORMAL);
+		m_skipEndStatus.add(EndStatusConstant.STRING_WARNING);
+		m_skipEndStatus.add(EndStatusConstant.STRING_ABNORMAL);
+
+		// スキップ終了値
 		composite = new Composite(m_skipEndConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -297,7 +306,7 @@ public class ControlComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 
 	}
 
@@ -325,18 +334,7 @@ public class ControlComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
-	@SuppressWarnings("unchecked")
 	public void reflectWaitRuleInfo() {
-
-		// 初期値
-		m_calendarCondition.setSelection(false);
-		m_calendarEndValue.setText(String
-				.valueOf(EndStatusConstant.INITIAL_VALUE_NORMAL));
-		m_waitCondition.setSelection(false);
-		m_skipCondition.setSelection(false);
-		m_skipEndValue.setText(String
-				.valueOf(EndStatusConstant.INITIAL_VALUE_NORMAL));
-
 		if (m_waitRule != null) {
 			//カレンダ
 			m_calendarCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule
@@ -345,28 +343,21 @@ public class ControlComposite extends Composite {
 			//カレンダID
 			if (m_waitRule.getCalendarId() != null &&
 					m_waitRule.getCalendarId().length() > 0) {
-				if (!m_calendarReadable) {
-					//カレンダー参照権限がない場合
-					m_calendarId.add(m_waitRule.getCalendarId());
-				}
-				m_calendarId.select(0);
-				for (int i = 0; i < m_calendarId.getItemCount(); i++) {
-					if (m_waitRule.getCalendarId().equals(m_calendarId.getItem(i))) {
-						m_calendarId.select(i);
-						break;
-					}
+				if (!m_calendarId.getEnabled()) {
+					// カレンダー参照権限が無い場合
+					m_calendarId.addText(m_waitRule.getCalendarId());
 				}
+				this.m_calendarId.setText(m_waitRule.getCalendarId());
 			}
 
+			//カレンダの終了状態
+			setSelectEndStatus(m_calendarEndStatus, m_waitRule.getCalendarEndStatus());
 			//カレンダ未実行時の終了値
 			m_calendarEndValue.setText(String.valueOf(m_waitRule.getCalendarEndValue()));
-
 			//保留
 			m_waitCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getSuspend()));
-
 			//スキップ
 			m_skipCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule.getSkip()));
-
 			//スキップ終了値
 			m_skipEndValue.setText(String.valueOf(m_waitRule.getSkipEndValue()));
 		}
@@ -374,11 +365,13 @@ public class ControlComposite extends Composite {
 		//カレンダ
 		if (m_calendarCondition.getSelection()) {
 			m_calendarConditionGroup.setEnabled(true);
-			m_calendarId.setEnabled(true & m_calendarReadable);
+			m_calendarId.setEnabled(true);
+			m_calendarEndStatus.setEnabled(true);
 			m_calendarEndValue.setEnabled(true);
 		} else {
 			m_calendarConditionGroup.setEnabled(false);
 			m_calendarId.setEnabled(false);
+			m_calendarEndStatus.setEnabled(false);
 			m_calendarEndValue.setEnabled(false);
 		}
 
@@ -390,12 +383,17 @@ public class ControlComposite extends Composite {
 		//スキップ
 		if (m_skipCondition.getSelection()) {
 			m_skipEndConditionGroup.setEnabled(true);
+			m_skipEndStatus.setEnabled(true);
 			m_skipEndValue.setEnabled(true);
 			m_waitCondition.setSelection(false);
 		} else {
 			m_skipEndConditionGroup.setEnabled(false);
+			m_skipEndStatus.setEnabled(false);
 			m_skipEndValue.setEnabled(false);
 		}
+
+		//スキップの終了状態
+		setSelectEndStatus(m_skipEndStatus, m_waitRule.getSkipEndStatus());
 	}
 
 	/**
@@ -423,47 +421,9 @@ public class ControlComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
-	@SuppressWarnings("unchecked")
 	public ValidateResult createWaitRuleInfo() {
 		ValidateResult result = null;
 
-		//実行内容情報クラスのインスタンスを作成・取得
-		if (m_waitRule == null) {
-			m_waitRule = new JobWaitRuleInfo();
-			m_waitRule.setSuspend(YesNoConstant.TYPE_NO);
-			m_waitRule.setSkip(YesNoConstant.TYPE_NO);
-			m_waitRule.setSkipEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setCondition(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setEndCondition(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setCalendar(YesNoConstant.TYPE_NO);
-			m_waitRule.setCalendarEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setStartDelay(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelaySession(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelaySessionValue(1);
-			m_waitRule.setStartDelayTime(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayConditionType(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setStartDelayNotify(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayOperation(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setEndDelay(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelaySession(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelaySessionValue(1);
-			m_waitRule.setEndDelayJob(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayJobValue(1);
-			m_waitRule.setEndDelayTime(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayConditionType(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setEndDelayNotify(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayOperation(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setSkipEndStatus(0);
-			m_waitRule.setEndStatus(0);
-			m_waitRule.setStartDelayNotifyPriority(0);
-			m_waitRule.setStartDelayOperationType(0);
-			m_waitRule.setEndDelayNotifyPriority(0);
-			m_waitRule.setEndDelayOperationType(0);
-		}
-
 		//カレンダ
 		m_waitRule.setCalendar(YesNoConstant.booleanToType(m_calendarCondition
 				.getSelection()));
@@ -487,6 +447,7 @@ public class ControlComposite extends Composite {
 
 		//カレンダ未実行時の終了値取得
 		try {
+			m_waitRule.setCalendarEndStatus(getSelectEndStatus(m_calendarEndStatus));
 			m_waitRule.setCalendarEndValue(Integer.parseInt(m_calendarEndValue.getText()));
 		} catch (NumberFormatException e) {
 			if (m_waitRule.getCalendar() == YesNoConstant.TYPE_YES) {
@@ -508,8 +469,8 @@ public class ControlComposite extends Composite {
 
 		//スキップ終了値取得
 		try {
-			m_waitRule.setSkipEndValue(Integer.parseInt(m_skipEndValue
-					.getText()));
+			m_waitRule.setSkipEndStatus(getSelectEndStatus(m_skipEndStatus));
+			m_waitRule.setSkipEndValue(Integer.parseInt(m_skipEndValue.getText()));
 		} catch (NumberFormatException e) {
 			if (m_waitRule.getSkip() == YesNoConstant.TYPE_YES) {
 				result = new ValidateResult();
@@ -522,4 +483,58 @@ public class ControlComposite extends Composite {
 
 		return null;
 	}
+
+
+	/**
+	 *終了状態用コンボボックスにて選択している項目を取得します。
+	 * 
+	 */
+	private int getSelectEndStatus(Combo combo) {
+		String select = combo.getText();
+		return EndStatusConstant.stringToType(select);
+	}
+
+	/**
+	 * 指定した重要度に該当する終了状態用コンボボックスの項目を選択します。
+	 * 
+	 */
+	private void setSelectEndStatus(Combo combo, int status) {
+		String select = "";
+
+		select = EndStatusConstant.typeToString(status);
+
+		combo.select(0);
+		for (int i = 0; i < combo.getItemCount(); i++) {
+			if (select.equals(combo.getItem(i))) {
+				combo.select(i);
+				break;
+			}
+		}
+	}
+
+	public CalendarIdListComposite getCalendarId() {
+		return m_calendarId;
+	}
+
+	public void setCalendarId(CalendarIdListComposite calendarId) {
+		this.m_calendarId = calendarId;
+	}
+	
+	/**
+	 * 読み込み専用時にグレーアウトします。
+	 */
+	@Override
+	public void setEnabled(boolean enabled) {
+		super.setEnabled(enabled);
+		m_waitCondition.setEnabled(enabled);
+		m_skipCondition.setEnabled(enabled);
+		m_skipEndStatus.setEnabled(enabled);
+		m_skipEndValue.setEnabled(enabled);
+		m_calendarCondition.setEnabled(enabled);
+		m_calendarId.setEnabled(enabled);
+		m_calendarEndStatus.setEnabled(enabled);
+		m_calendarEndValue.setEnabled(enabled);
+	}
+
+
 }
\ No newline at end of file
