@@ -18,7 +18,6 @@ package com.clustercontrol.jobmanagement.composite;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.jface.dialogs.IDialogConstants;
@@ -32,6 +31,7 @@ import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.layout.RowData;
 import org.eclipse.swt.layout.RowLayout;
 import org.eclipse.swt.widgets.Button;
+import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
@@ -44,8 +44,7 @@ import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.composite.CommonTableViewer;
-import com.clustercontrol.composite.NumberVerifyListener;
+import com.clustercontrol.composite.action.NumberVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.action.GetWaitRuleTableDefine;
 import com.clustercontrol.jobmanagement.bean.ConditionTypeConstant;
@@ -53,6 +52,7 @@ import com.clustercontrol.jobmanagement.bean.JudgmentObjectConstant;
 import com.clustercontrol.jobmanagement.composite.action.WaitRuleSelectionChangedListener;
 import com.clustercontrol.jobmanagement.dialog.WaitRuleDialog;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.jobmanagement.JobObjectInfo;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
@@ -65,29 +65,31 @@ import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
  */
 public class WaitRuleComposite extends Composite {
 	/** テーブルビューア */
-	protected CommonTableViewer m_viewer = null;
+	private CommonTableViewer m_viewer = null;
 	/** 判定対象の条件関係 AND用ラジオボタン */
-	protected Button m_andCondition = null;
+	private Button m_andCondition = null;
 	/** 判定対象の条件関係 OR用ラジオボタン */
-	protected Button m_orCondition = null;
+	private Button m_orCondition = null;
 	/** 条件を満たさなければ終了する用チェックボタン */
-	protected Button m_endCondition = null;
+	private Button m_endCondition = null;
 	/** 条件を満たさなければ終了する用グループ */
-	protected Group m_endConditionGroup = null;
+	private Group m_endConditionGroup = null;
+	/** 条件を満たさない時の終了状態用テキスト */
+	private Combo m_endStatus = null;
 	/** 条件を満たさない時の終了値用テキスト */
-	protected Text m_endValue = null;
+	private Text m_endValue = null;
 	/** 追加用ボタン */
-	protected Button m_createCondition = null;
+	private Button m_createCondition = null;
 	/** 変更用ボタン */
-	protected Button m_modifyCondition = null;
+	private Button m_modifyCondition = null;
 	/** 削除用ボタン */
-	protected Button m_deleteCondition = null;
+	private Button m_deleteCondition = null;
 	/** ジョブ待ち条件情報 */
-	protected JobWaitRuleInfo m_waitRule = null;
+	private JobWaitRuleInfo m_waitRule = null;
 	/** シェル */
-	protected Shell m_shell = null;
+	private Shell m_shell = null;
 	/** 選択アイテム */
-	protected ArrayList m_selectItem = null;
+	private ArrayList m_selectItem = null;
 
 	private JobTreeItem m_jobTreeItem = null;
 
@@ -134,7 +136,7 @@ public class WaitRuleComposite extends Composite {
 				| SWT.V_SCROLL | SWT.FULL_SELECTION | SWT.SINGLE);
 		table.setHeaderVisible(true);
 		table.setLinesVisible(true);
-		table.setLayoutData(new RowData(430, 80));
+		table.setLayoutData(new RowData(430, 130));
 
 		composite = new Composite(composite, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -160,9 +162,9 @@ public class WaitRuleComposite extends Composite {
 					boolean addWaitRule = true;
 
 					ArrayList info = dialog.getInputData();
-					ArrayList list = (ArrayList) m_viewer.getInput();
+					ArrayList<ArrayList<Integer>> list = (ArrayList<ArrayList<Integer>>) m_viewer.getInput();
 					if (list == null) {
-						list = new ArrayList();
+						list = new ArrayList<ArrayList<Integer>>();
 
 					} else {
 
@@ -170,10 +172,8 @@ public class WaitRuleComposite extends Composite {
 						int newWaitRuleType = (Integer) info.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
 						if (newWaitRuleType == JudgmentObjectConstant.TYPE_TIME){
 
-							Iterator itr = list.iterator();
-							while (itr.hasNext()) {
-								ArrayList waitRule = (ArrayList) itr.next();
-								int rule = (Integer) waitRule.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
+							for (ArrayList<Integer> waitRule : list) {
+								int rule = waitRule.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
 								if (rule == JudgmentObjectConstant.TYPE_TIME) {
 									addWaitRule = false;
 
@@ -199,7 +199,6 @@ public class WaitRuleComposite extends Composite {
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_modifyCondition.addSelectionListener(new SelectionAdapter() {
 			@Override
-			@SuppressWarnings("unchecked")
 			public void widgetSelected(SelectionEvent e) {
 				WaitRuleDialog dialog = new WaitRuleDialog(m_shell, m_jobTreeItem);
 				if (m_selectItem instanceof ArrayList) {
@@ -207,7 +206,7 @@ public class WaitRuleComposite extends Composite {
 					if (dialog.open() == IDialogConstants.OK_ID) {
 
 						ArrayList info = dialog.getInputData();
-						ArrayList list = (ArrayList) m_viewer.getInput();
+						ArrayList<ArrayList> list = (ArrayList<ArrayList>) m_viewer.getInput();
 
 						list.remove(m_selectItem);
 						list.add(info);
@@ -229,14 +228,10 @@ public class WaitRuleComposite extends Composite {
 		m_deleteCondition.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				if (m_selectItem instanceof ArrayList) {
-					ArrayList list = (ArrayList) m_viewer.getInput();
-					list.remove(m_selectItem);
-					m_selectItem = null;
-					m_viewer.setInput(list);
-				} else {
-
-				}
+				ArrayList list = (ArrayList) m_viewer.getInput();
+				list.remove(m_selectItem);
+				m_selectItem = null;
+				m_viewer.setInput(list);
 			}
 		});
 
@@ -283,9 +278,11 @@ public class WaitRuleComposite extends Composite {
 				Button check = (Button) e.getSource();
 				if (check.getSelection()) {
 					m_endConditionGroup.setEnabled(true);
+					m_endStatus.setEnabled(true);
 					m_endValue.setEnabled(true);
 				} else {
 					m_endConditionGroup.setEnabled(false);
+					m_endStatus.setEnabled(false);
 					m_endValue.setEnabled(false);
 				}
 				update();
@@ -305,6 +302,24 @@ public class WaitRuleComposite extends Composite {
 		rowLayout.spacing = 1;
 		m_endConditionGroup.setLayout(rowLayout);
 
+		// 終了状態
+		composite = new Composite(m_endConditionGroup, SWT.NONE);
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.spacing = 10;
+		composite.setLayout(rowLayout);
+		Label endStatusTitle = new Label(composite, SWT.LEFT);
+		endStatusTitle.setText(Messages.getString("end.status") + " : ");
+		endStatusTitle.setLayoutData(new RowData(80,
+				SizeConstant.SIZE_LABEL_HEIGHT));
+		m_endStatus = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_endStatus.setLayoutData(new RowData(100,
+				SizeConstant.SIZE_COMBO_HEIGHT));
+		m_endStatus.add(EndStatusConstant.STRING_NORMAL);
+		m_endStatus.add(EndStatusConstant.STRING_WARNING);
+		m_endStatus.add(EndStatusConstant.STRING_ABNORMAL);
+
+		// 終了値
 		composite = new Composite(m_endConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -315,8 +330,7 @@ public class WaitRuleComposite extends Composite {
 		endValueTitle.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		m_endValue = new Text(composite, SWT.BORDER);
-		m_endValue
-		.setLayoutData(new RowData(100, SizeConstant.SIZE_TEXT_HEIGHT));
+		m_endValue.setLayoutData(new RowData(100, SizeConstant.SIZE_TEXT_HEIGHT));
 		m_endValue.addVerifyListener(
 				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
 		m_endValue.addModifyListener(
@@ -326,7 +340,7 @@ public class WaitRuleComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 
 		m_viewer = new CommonTableViewer(table);
 		m_viewer.createTableColumn(GetWaitRuleTableDefine.get(),
@@ -353,13 +367,6 @@ public class WaitRuleComposite extends Composite {
 	 */
 	@SuppressWarnings("unchecked")
 	public void reflectWaitRuleInfo() {
-
-		// 初期値
-		m_andCondition.setSelection(true);
-		m_endCondition.setSelection(false);
-		m_endValue.setText(String
-				.valueOf(EndStatusConstant.INITIAL_VALUE_NORMAL));
-
 		if (m_waitRule != null) {
 			//判定対象と開始条件値設定
 			List<JobObjectInfo> list = m_waitRule.getObject();
@@ -372,20 +379,21 @@ public class WaitRuleComposite extends Composite {
 					if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
 						tableLineData.add(info.getJobId());
 						tableLineData.add(EndStatusConstant.typeToString(info.getValue()));
+						tableData.add(tableLineData);
 					}
 					else if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_VALUE) {
 						tableLineData.add(info.getJobId());
 						tableLineData.add(new Integer(info.getValue()));
+						tableData.add(tableLineData);
 					}
 					else {
-						tableLineData.add("");
 						if (info.getTime() != null) {
-							tableLineData.add(new Date(info.getTime()));
-						} else {
 							tableLineData.add("");
+							tableLineData.add(new Date(info.getTime()));
+							tableData.add(tableLineData);
+						} else {
 						}
 					}
-					tableData.add(tableLineData);
 				}
 				m_viewer.setInput(tableData);
 			}
@@ -403,6 +411,9 @@ public class WaitRuleComposite extends Composite {
 			m_endCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule
 					.getEndCondition()));
 
+			//終了状態
+			setSelectEndStatus(m_endStatus, m_waitRule.getEndStatus());
+
 			//終了値
 			m_endValue.setText(String.valueOf(m_waitRule.getEndValue()));
 		}
@@ -410,9 +421,11 @@ public class WaitRuleComposite extends Composite {
 		//開始条件を満たさないとき終了
 		if (m_endCondition.getSelection()) {
 			m_endConditionGroup.setEnabled(true);
+			m_endStatus.setEnabled(true);
 			m_endValue.setEnabled(true);
 		} else {
 			m_endConditionGroup.setEnabled(false);
+			m_endStatus.setEnabled(false);
 			m_endValue.setEnabled(false);
 		}
 	}
@@ -436,28 +449,27 @@ public class WaitRuleComposite extends Composite {
 	}
 
 	public static JobObjectInfo array2JobObjectInfo(ArrayList tableLineData) {
-		Integer type = (Integer) tableLineData
-		.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
+		Integer type = (Integer) tableLineData.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
 		JobObjectInfo info = new JobObjectInfo();
 		info.setValue(0);
-		info.setType(type.intValue());
+		info.setType(type);
 		if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
 			info.setJobId((String) tableLineData
 					.get(GetWaitRuleTableDefine.JOB_ID));
 			String value = (String) tableLineData
-			.get(GetWaitRuleTableDefine.START_VALUE);
+					.get(GetWaitRuleTableDefine.START_VALUE);
 			info.setValue(EndStatusConstant.stringToType(value));
 		}
 		else if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_VALUE) {
 			info.setJobId((String) tableLineData
 					.get(GetWaitRuleTableDefine.JOB_ID));
 			Integer value = (Integer) tableLineData
-			.get(GetWaitRuleTableDefine.START_VALUE);
-			info.setValue(value.intValue());
+					.get(GetWaitRuleTableDefine.START_VALUE);
+			info.setValue(value);
 		}
 		else {
 			Date value = (Date) tableLineData
-			.get(GetWaitRuleTableDefine.START_VALUE);
+					.get(GetWaitRuleTableDefine.START_VALUE);
 			info.setTime(value.getTime());
 		}
 		return info;
@@ -470,76 +482,37 @@ public class WaitRuleComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
-	@SuppressWarnings("unchecked")
 	public ValidateResult createWaitRuleInfo() {
 		ValidateResult result = null;
 
-		//実行内容情報クラスのインスタンスを作成・取得
-		if (m_waitRule == null) {
-			m_waitRule = new JobWaitRuleInfo();
-			m_waitRule.setSuspend(YesNoConstant.TYPE_NO);
-			m_waitRule.setSkip(YesNoConstant.TYPE_NO);
-			m_waitRule.setSkipEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setCondition(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setEndCondition(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setCalendar(YesNoConstant.TYPE_NO);
-			m_waitRule.setCalendarEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setStartDelay(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelaySession(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelaySessionValue(1);
-			m_waitRule.setStartDelayTime(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayConditionType(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setStartDelayNotify(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayOperation(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setEndDelay(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelaySession(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelaySessionValue(1);
-			m_waitRule.setEndDelayJob(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayJobValue(1);
-			m_waitRule.setEndDelayTime(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayConditionType(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setEndDelayNotify(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayOperation(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setSkipEndStatus(0);
-			m_waitRule.setEndStatus(0);
-			m_waitRule.setStartDelayNotifyPriority(0);
-			m_waitRule.setStartDelayOperationType(0);
-			m_waitRule.setEndDelayNotifyPriority(0);
-			m_waitRule.setEndDelayOperationType(0);
-		}
 		//判定対象と開始条件値取得
 		ArrayList<JobObjectInfo> list = new ArrayList<JobObjectInfo>();
 		ArrayList tableData = (ArrayList) m_viewer.getInput();
 		HashMap<String, Integer> map = new HashMap<String, Integer>();
-		if (tableData instanceof ArrayList) {
-			for (int i = 0; i < tableData.size(); i++) {
-				ArrayList tableLineData = (ArrayList) tableData.get(i);
-				JobObjectInfo info = array2JobObjectInfo(tableLineData);
-				// 重複チェックをしてから、リストに追加する。
-				if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
-					Integer checkValue = map.get(info.getJobId() + info.getType());
-					if (checkValue == null
-							|| checkValue.intValue() != info.getValue()) {
-						list.add(info);
-						map.put(info.getJobId() + info.getType(), new Integer(info.getValue()));
-					}
+		for (int i = 0; i < tableData.size(); i++) {
+			ArrayList tableLineData = (ArrayList) tableData.get(i);
+			JobObjectInfo info = array2JobObjectInfo(tableLineData);
+			// 重複チェックをしてから、リストに追加する。
+			if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
+				Integer checkValue = map.get(info.getJobId() + info.getType());
+				if (checkValue == null
+						|| checkValue != info.getValue()) {
+					list.add(info);
+					map.put(info.getJobId() + info.getType(), new Integer(info.getValue()));
 				}
-				else if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_VALUE) {
-					Integer checkValue = map.get(info.getJobId() + info.getType());
-					if (checkValue == null
-							|| checkValue.intValue() != info.getValue()) {
-						list.add(info);
-						map.put(info.getJobId() + info.getType(), new Integer(info.getValue()));
-					}
+			}
+			else if (info.getType() == JudgmentObjectConstant.TYPE_JOB_END_VALUE) {
+				Integer checkValue = map.get(info.getJobId() + info.getType());
+				if (checkValue == null
+						|| checkValue != info.getValue()) {
+					list.add(info);
+					map.put(info.getJobId() + info.getType(), new Integer(info.getValue()));
 				}
-				else {
-					if (map.get("TIME") == null) {
-						list.add(info);
-						map.put("TIME", 1);
-					}
+			}
+			else {
+				if (map.get("TIME") == null) {
+					list.add(info);
+					map.put("TIME", 1);
 				}
 			}
 		}
@@ -558,8 +531,9 @@ public class WaitRuleComposite extends Composite {
 		m_waitRule.setEndCondition(YesNoConstant.booleanToType(m_endCondition
 				.getSelection()));
 
-		//終了値取得
+		//終了状態、終了値
 		try {
+			m_waitRule.setEndStatus(getSelectEndStatus(m_endStatus));
 			m_waitRule.setEndValue(Integer.parseInt(m_endValue.getText()));
 		} catch (NumberFormatException e) {
 			if (m_waitRule.getEndCondition() == YesNoConstant.TYPE_YES) {
@@ -574,15 +548,6 @@ public class WaitRuleComposite extends Composite {
 		return null;
 	}
 
-	/**
-	 * 選択アイテムを返します。
-	 * 
-	 * @return 選択アイテム
-	 */
-	public ArrayList getSelectItem() {
-		return m_selectItem;
-	}
-
 	/**
 	 * 選択アイテムを設定します。
 	 * 
@@ -592,12 +557,51 @@ public class WaitRuleComposite extends Composite {
 		m_selectItem = selectItem;
 	}
 
-	public JobTreeItem getJobTreeItem() {
-		return m_jobTreeItem;
-	}
-
 	public void setJobTreeItem(JobTreeItem jobTreeItem) {
 		m_jobTreeItem = jobTreeItem;
 	}
 
+	/**
+	 * 指定した重要度に該当するカレンダ終了状態用コンボボックスの項目を選択します。
+	 * 
+	 */
+	private void setSelectEndStatus(Combo combo, int status) {
+		String select = "";
+
+		select = EndStatusConstant.typeToString(status);
+
+		combo.select(0);
+		for (int i = 0; i < combo.getItemCount(); i++) {
+			if (select.equals(combo.getItem(i))) {
+				combo.select(i);
+				break;
+			}
+		}
+	}
+
+	/**
+	 * カレンダ終了状態用コンボボックスにて選択している項目を取得します。
+	 * 
+	 */
+	private int getSelectEndStatus(Combo combo) {
+		String select = combo.getText();
+		return EndStatusConstant.stringToType(select);
+	}
+	
+	/**
+	 * 読み込み専用時にグレーアウトします。
+	 */
+	@Override
+	public void setEnabled(boolean enabled) {
+		// super.setEnabled(enabled); // スクロールバーを動かせるように、ここはコメントアウト
+		m_andCondition.setEnabled(enabled);
+		m_orCondition.setEnabled(enabled);
+		m_endCondition.setEnabled(enabled);
+		m_endConditionGroup.setEnabled(enabled);
+		m_endStatus.setEnabled(enabled);
+		m_endValue.setEnabled(enabled);
+		m_createCondition.setEnabled(enabled);
+		m_modifyCondition.setEnabled(enabled);
+		m_deleteCondition.setEnabled(enabled);
+	}
 }
\ No newline at end of file
