@@ -28,9 +28,7 @@ import org.eclipse.ui.PlatformUI;
 import com.clustercontrol.jobmanagement.action.GetJobTableDefine;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.composite.JobListComposite;
-import com.clustercontrol.jobmanagement.util.JobUtil;
 import com.clustercontrol.jobmanagement.view.JobListView;
-import com.clustercontrol.util.LoginManager;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 
 /**
@@ -41,7 +39,7 @@ import com.clustercontrol.ws.jobmanagement.JobTreeItem;
  */
 public class JobListSelectionChangedListener implements ISelectionChangedListener {
 	/** ジョブ[一覧]ビュー用のコンポジット */
-	protected JobListComposite m_list;
+	private JobListComposite m_list;
 
 	/**
 	 * コンストラクタ
@@ -74,7 +72,7 @@ public class JobListSelectionChangedListener implements ISelectionChangedListene
 
 		//ジョブ[登録]ビューのインスタンスを取得
 		IWorkbenchPage page = PlatformUI.getWorkbench()
-		.getActiveWorkbenchWindow().getActivePage();
+				.getActiveWorkbenchWindow().getActivePage();
 		IViewPart viewPart = page.findView(JobListView.ID);
 
 
@@ -104,22 +102,14 @@ public class JobListSelectionChangedListener implements ISelectionChangedListene
 				//選択ツリーアイテムを設定
 				m_list.setSelectJobTreeItem(selectJobTreeItem);
 
-				boolean isReferableJobunit = false;
-
 				// ログインユーザで参照可能なジョブユニットかどうかチェックする
 				if (selectJobTreeItem.getData().getType() == JobConstant.TYPE_JOBUNIT) {
-
-					// 参照できない場合、各種ボタン操作を無効化する
-					if (JobUtil.isReferableJobunit(selectJobTreeItem, LoginManager.getContextManager().getUserId())) {
-						view.setEnabledActionAll(true);
-						view.setEnabledAction(selectJobTreeItem.getData().getType(), selection);
-					} else {
-						view.setEnabledActionAll(false);
-					}
-
+					//ビューのアクションの有効/無効を設定
+					view.setEnabledActionAll(true);
+					view.setEnabledAction(selectJobTreeItem.getData().getType(), selectJobTreeItem.getData().getJobunitId(), selection);
 				} else {
 					//ビューのアクションの有効/無効を設定
-					view.setEnabledAction(selectJobTreeItem.getData().getType(), selection);
+					view.setEnabledAction(selectJobTreeItem.getData().getType(), selectJobTreeItem.getData().getJobunitId(), selection);
 				}
 			} else {
 				//選択ツリーアイテムを設定
