@@ -24,13 +24,18 @@ import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.swt.widgets.Composite;
+import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.PlatformUI;
 
 import com.clustercontrol.jobmanagement.action.GetHistoryTableDefine;
+import com.clustercontrol.jobmanagement.action.GetPlanTableDefine;
 import com.clustercontrol.jobmanagement.composite.DetailComposite;
 import com.clustercontrol.jobmanagement.composite.HistoryComposite;
+import com.clustercontrol.jobmanagement.composite.JobPlanComposite;
 import com.clustercontrol.jobmanagement.dialog.JobDialog;
 import com.clustercontrol.jobmanagement.util.JobEndpointWrapper;
+import com.clustercontrol.jobmanagement.view.JobListView;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.JobInfo;
@@ -47,13 +52,13 @@ public class SessionJobDoubleClickListener implements IDoubleClickListener {
 	// ログ
 	private static Log m_log = LogFactory.getLog( SessionJobDoubleClickListener.class );
 
-	/** ジョブ[履歴]ビューまたはジョブ[ジョブ詳細]ビュー用のコンポジット */
-	protected Composite m_composite;
+	/** ジョブ[履歴]ビュー、ジョブ[ジョブ詳細]ビュー、ジョブ[スケジュール予定]用のコンポジット */
+	private Composite m_composite;
 
 	/**
 	 * コンストラクタ
 	 * 
-	 * @param composite ジョブ[履歴]ビューまたはジョブ[ジョブ詳細]ビュー用のコンポジット
+	 * @param composite ジョブ[履歴]ビュー、ジョブ[ジョブ詳細]ビュー、ジョブ[スケジュール予定]用のコンポジット
 	 */
 	public SessionJobDoubleClickListener(Composite composite) {
 		m_composite = composite;
@@ -61,7 +66,10 @@ public class SessionJobDoubleClickListener implements IDoubleClickListener {
 
 	/**
 	 * ダブルクリック時に呼び出されます。<BR>
-	 * ジョブ[履歴]ビューまたはジョブ[ジョブ詳細]ビューのテーブルビューアをダブルクリックした際に、選択した行の内容をダイアログで表示します。
+	 * ジョブ[履歴]ビュー、
+	 * ジョブ[ジョブ詳細]ビュー、
+	 * ジョブ[スケジュール予定]ビュー
+	 * のテーブルビューアをダブルクリックした際に、選択した行の内容をダイアログで表示します。
 	 * <P>
 	 * <ol>
 	 * <li>イベントから選択行を取得し、選択行からセッションIDとジョブIDを取得します。</li>
@@ -99,6 +107,22 @@ public class SessionJobDoubleClickListener implements IDoubleClickListener {
 				jobId = info.getId();
 			}
 		}
+		//ジョブ[スケジュール予定]ビューダブルクリックの処理 (ジョブ[一覧]のツリーの該当ノードをフォーカス)
+		else if(m_composite instanceof JobPlanComposite){
+			if (((StructuredSelection) event.getSelection()).getFirstElement() != null) {
+				ArrayList plan = (ArrayList) ((StructuredSelection) event
+						.getSelection()).getFirstElement();
+				jobId = (String)plan.get(GetPlanTableDefine.JOB_ID);
+				//アクティブページを手に入れる
+				IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
+				IViewPart viewPart = page.findView(JobListView.ID);
+				if (viewPart != null) {
+					JobListView view = (JobListView) viewPart
+							.getAdapter(JobListView.class);
+					view.update(jobId);
+				}
+			}
+		}
 
 		if(sessionId != null && sessionId.length() > 0 &&
 				jobunitId != null && jobunitId.length() > 0 &&
