@@ -34,7 +34,7 @@ import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 /**
  * ジョブ選択ダイアログクラスです。
  * 
- * @version 1.0.0
+ * @version 4.1.0
  * @since 1.0.0
  */
 public class JobTreeDialog extends CommonDialog {
@@ -45,14 +45,28 @@ public class JobTreeDialog extends CommonDialog {
 	private boolean m_treeOnly = false;
 
 	private JobTreeItem m_jobTreeItem = null;
+
+	/** オーナーロールID **/
+	private String ownerRoleId = null;
+
+	/**
+	 * 表示ツリーの形式
+	 * 値として、JobConstantクラスで定義したものが入る
+	 * @see com.clustercontrol.jobmanagement.bean.JobConstant
+	 *  -1 : 未選択<BR>
+	 *  TYPE_REFERJOB以外: 選択したユニット、ネットの子のみ表示する<BR>
+	 *  TYPE_REFERJOB : 選択したユニット、ネットの所属するジョブユニット以下すべて表示する<BR>
+	 */
+	private int mode = -1;
+
 	/**
 	 * コンストラクタ
 	 * 
 	 * @param parent 親シェル
 	 */
-	public JobTreeDialog(Shell parent) {
+	public JobTreeDialog(Shell parent, String ownerRoleId) {
 		super(parent);
-
+		this.ownerRoleId = ownerRoleId;
 		m_treeOnly = false;
 	}
 
@@ -62,8 +76,9 @@ public class JobTreeDialog extends CommonDialog {
 	 * @param parent 親シェル
 	 * @param treeOnly true：ツリーのみ、false：ジョブ情報を含む
 	 */
-	public JobTreeDialog(Shell parent, boolean treeOnly) {
+	public JobTreeDialog(Shell parent, String ownerRoleId, boolean treeOnly) {
 		super(parent);
+		this.ownerRoleId = ownerRoleId;
 		m_treeOnly = treeOnly;
 	}
 
@@ -74,12 +89,27 @@ public class JobTreeDialog extends CommonDialog {
 	 * @param parentJobId 親ジョブID
 	 * @param jobId ジョブID
 	 */
-	public JobTreeDialog(Shell parent, JobTreeItem jobTreeItem) {
+	public JobTreeDialog(Shell parent, String ownerRoleId, JobTreeItem jobTreeItem) {
 		super(parent);
+		this.ownerRoleId = ownerRoleId;
 		m_jobTreeItem = jobTreeItem;
 		m_treeOnly = true;
 	}
 
+	/**
+	 * コンストラクタ
+	 * @param parent 親シェル
+	 * @param jobTreeItem
+	 * @param mode 表示ツリーの形式
+	 */
+	public JobTreeDialog(Shell parent, String ownerRoleId, JobTreeItem jobTreeItem, int mode) {
+		super(parent);
+		this.ownerRoleId = ownerRoleId;
+		m_jobTreeItem = jobTreeItem;
+		m_treeOnly = true;
+		this.mode = mode;
+	}
+
 	/**
 	 * ダイアログの初期サイズを返します。
 	 * 
@@ -108,9 +138,14 @@ public class JobTreeDialog extends CommonDialog {
 		layout.marginWidth = 0;
 
 		if (m_jobTreeItem == null) {
-			treeComposite = new JobTreeComposite(parent, SWT.NONE, m_treeOnly);
-		} else {
-			treeComposite = new JobTreeComposite(parent, SWT.NONE, m_jobTreeItem);
+			treeComposite = new JobTreeComposite(parent, SWT.NONE, ownerRoleId, m_treeOnly, false);
+		}
+		//参照ジョブでは、選択したジョブネット、ジョブが所属するジョブユニット配下すべて表示させる
+		else if (this.mode == JobConstant.TYPE_REFERJOB) {
+			treeComposite = new JobTreeComposite(parent, SWT.NONE, ownerRoleId, m_jobTreeItem, mode);
+		}
+		else {
+			treeComposite = new JobTreeComposite(parent, SWT.NONE, ownerRoleId, m_jobTreeItem);
 		}
 
 		GridData gridData = new GridData();
@@ -159,6 +194,16 @@ public class JobTreeDialog extends CommonDialog {
 				result.setID(Messages.getString("message.hinemos.1"));
 				result.setMessage(Messages.getString("message.job.1"));
 			}
+			//参照ジョブの場合、ジョブ以外は選択不可
+			else if (mode == JobConstant.TYPE_REFERJOB) {
+				if (item.getData().getType() != JobConstant.TYPE_JOB &&
+						item.getData().getType() != JobConstant.TYPE_FILEJOB) {
+					result = new ValidateResult();
+					result.setValid(false);
+					result.setID(Messages.getString("message.hinemos.1"));
+					result.setMessage(Messages.getString("message.job.1"));
+				}
+			}
 		} else {
 			result = new ValidateResult();
 			result.setValid(false);
