@@ -27,14 +27,17 @@ import javax.persistence.EntityManager;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.accesscontrol.util.ObjectPrivilegeUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.JobInvalid;
 import com.clustercontrol.fault.JobMasterDuplicate;
 import com.clustercontrol.fault.JobMasterNotFound;
+import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.bean.JobEndStatusInfo;
 import com.clustercontrol.jobmanagement.bean.JobInfo;
@@ -167,13 +170,23 @@ public class ModifyJob {
 	 * @throws JobInvalid
 	 * 
 	 */
-	public void deleteJobunit(String jobunitId, String userId) throws HinemosUnknown, JobMasterNotFound, JobInvalid {
+	public void deleteJobunit(String jobunitId, String userId) throws HinemosUnknown, JobMasterNotFound, JobInvalid, ObjectPrivilege_InvalidRole {
 		EntityManager em = new JpaTransactionManager().getEntityManager();
 
 		// 引数で指定されたジョブユニットIDを持つジョブユニットを取得
 		Collection<JobMstEntity> ct =
-				em.createNamedQuery("JobMstEntity.findByJobunitId", JobMstEntity.class)
+				((HinemosEntityManager)em).createNamedQuery("JobMstEntity.findByJobunitId", JobMstEntity.class, ObjectPrivilegeMode.WRITE)
 				.setParameter("jobunitId", jobunitId).getResultList();
+		
+		// オブジェクト権限チェック(削除対象のリストが空だった場合)
+		if (ct == null || ct.size() == 0) {
+			ObjectPrivilege_InvalidRole e = new ObjectPrivilege_InvalidRole(
+					"targetClass = " + JobMstEntity.class.getSimpleName());
+			m_log.info("deleteJobunit() : object privilege invalid. jobunitId = " + jobunitId);
+
+			throw e;
+		}
+		
 		for (JobMstEntity jobMstEntity : ct) {
 			deleteJob(jobMstEntity);
 		}
