@@ -28,6 +28,7 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.commons.scheduler.QuartzUtil;
+import com.clustercontrol.commons.util.EmptyJpaTransactionCallback; 
 import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.HinemosUnknown;
@@ -70,7 +71,7 @@ public class ModifyJobKick {
 	 * @see com.clustercontrol.jobmanagement.bean.JobTriggerInfo
 	 * @see com.clustercontrol.jobmanagement.util.QuartzUtil#getQuartzManager()
 	 */
-	public void addSchedule(JobSchedule info, String loginUser) throws HinemosUnknown, JobKickDuplicate {
+	public void addSchedule(final JobSchedule info, String loginUser) throws HinemosUnknown, JobKickDuplicate {
 		m_log.debug("addSchedule() : id=" + info.getId() + ", jobId=" + info.getJobId());
 		JpaTransactionManager jtm = new JpaTransactionManager();
 		//最終更新日時を設定
@@ -109,43 +110,53 @@ public class ModifyJobKick {
 					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			throw new HinemosUnknown(e.getMessage(), e);
 		}
-		//実行契機情報の作成
-		JobTriggerInfo triggerInfo = new JobTriggerInfo();
-		triggerInfo.setTrigger_type(JobTriggerTypeConstant.TYPE_SCHEDULE);
-		triggerInfo.setTrigger_info(info.getName()+"("+info.getId()+")");
+		
+		jtm.addCallback(new EmptyJpaTransactionCallback() { 
+			@Override
+			public void postCommit() {
+				//実行契機情報の作成
+				JobTriggerInfo triggerInfo = new JobTriggerInfo();
+				triggerInfo.setTrigger_type(JobTriggerTypeConstant.TYPE_SCHEDULE);
+				triggerInfo.setTrigger_info(info.getName()+"("+info.getId()+")");
 
-		//JobDetailに呼び出すメソッドの引数を設定
-		Object[] jdArgs = new Object[QuartzConstant.ARGS_NUM];
-		Class[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
-		//ジョブユニットIDを設定
-		jdArgs[QuartzConstant.INDEX_JOBUNIT_ID] = info.getJobunitId();
-		jdArgsType[QuartzConstant.INDEX_JOBUNIT_ID] = String.class;
+				//JobDetailに呼び出すメソッドの引数を設定
+				Object[] jdArgs = new Object[QuartzConstant.ARGS_NUM];
+				Class[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
+				//ジョブユニットIDを設定
+				jdArgs[QuartzConstant.INDEX_JOBUNIT_ID] = info.getJobunitId();
+				jdArgsType[QuartzConstant.INDEX_JOBUNIT_ID] = String.class;
 
-		//ジョブIDを設定
-		jdArgs[QuartzConstant.INDEX_JOB_ID] = info.getJobId();
-		jdArgsType[QuartzConstant.INDEX_JOB_ID] = String.class;
+				//ジョブIDを設定
+				jdArgs[QuartzConstant.INDEX_JOB_ID] = info.getJobId();
+				jdArgsType[QuartzConstant.INDEX_JOB_ID] = String.class;
 
-		//カレンダIDを設定
-		jdArgs[QuartzConstant.INDEX_CALENDAR_ID] = info.getCalendarId();
-		jdArgsType[QuartzConstant.INDEX_CALENDAR_ID] = String.class;
+				//カレンダIDを設定
+				jdArgs[QuartzConstant.INDEX_CALENDAR_ID] = info.getCalendarId();
+				jdArgsType[QuartzConstant.INDEX_CALENDAR_ID] = String.class;
 
-		//実行契機情報を設定
-		jdArgs[QuartzConstant.INDEX_TRIGGER_INFO] = triggerInfo;
-		jdArgsType[QuartzConstant.INDEX_TRIGGER_INFO] = JobTriggerInfo.class;
+				//実行契機情報を設定
+				jdArgs[QuartzConstant.INDEX_TRIGGER_INFO] = triggerInfo;
+				jdArgsType[QuartzConstant.INDEX_TRIGGER_INFO] = JobTriggerInfo.class;
 
-		//Cron表記へ変換
-		String cronString = QuartzUtil.getCronString(info.getScheduleType(),
-				info.getWeek(),info.getHour(),info.getMinute(),
-				info.getFromXminutes(),info.getEveryXminutes());
+				//Cron表記へ変換
+				String cronString = QuartzUtil.getCronString(info.getScheduleType(),
+						info.getWeek(),info.getHour(),info.getMinute(),
+						info.getFromXminutes(),info.getEveryXminutes());
 
-		m_log.trace("CronString =" + cronString);
+				m_log.trace("CronString =" + cronString);
 
-		// スケジュール定義を登録
-		SchedulerPlugin.scheduleCronJob(SchedulerType.DBMS, info.getId(), QuartzConstant.GROUP_NAME, new Date(System.currentTimeMillis() + 15 * 1000), cronString,
-				true, JobControllerBean.class.getName(), QuartzConstant.METHOD_NAME, jdArgsType, jdArgs);
-		if (! ValidConstant.typeToBoolean(info.getValid())) {
-			SchedulerPlugin.pauseJob(SchedulerType.DBMS, info.getId(), QuartzConstant.GROUP_NAME);
-		}
+				// スケジュール定義を登録
+				try {
+					SchedulerPlugin.scheduleCronJob(SchedulerType.DBMS, info.getId(), QuartzConstant.GROUP_NAME, new Date(System.currentTimeMillis() + 15 * 1000), cronString,
+							true, JobControllerBean.class.getName(), QuartzConstant.METHOD_NAME, jdArgsType, jdArgs);
+					if (! ValidConstant.typeToBoolean(info.getValid())) {
+						SchedulerPlugin.pauseJob(SchedulerType.DBMS, info.getId(), QuartzConstant.GROUP_NAME);
+					}
+				} catch (HinemosUnknown e) {
+					m_log.error(e);
+				}
+			}
+		});
 	}
 	/**
 	 * ファイルチェック情報をDBに反映します。<BR>
@@ -233,7 +244,7 @@ public class ModifyJobKick {
 	 * @throws HinemosUnknown
 	 * @throws JobInfoNotFound
 	 */
-	public void modifySchedule(JobSchedule info, String loginUser) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole{
+	public void modifySchedule(final JobSchedule info, String loginUser) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole{
 		m_log.debug("modifySchedule() : id=" + info.getId() + ", jobId=" + info.getJobId());
 		JpaTransactionManager jtm = new JpaTransactionManager();
 		EntityManager em = jtm.getEntityManager();
@@ -282,43 +293,54 @@ public class ModifyJobKick {
 					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			throw new HinemosUnknown(e.getMessage(), e);
 		}
-		//実行契機情報の作成
-		JobTriggerInfo triggerInfo = new JobTriggerInfo();
-		triggerInfo.setTrigger_type(JobTriggerTypeConstant.TYPE_SCHEDULE);
-		triggerInfo.setTrigger_info(info.getName()+"("+info.getId()+")");
+		
+		jtm.addCallback(new EmptyJpaTransactionCallback() { 
+			@Override
+			public void postCommit() {
+				//実行契機情報の作成
+				JobTriggerInfo triggerInfo = new JobTriggerInfo();
+				triggerInfo.setTrigger_type(JobTriggerTypeConstant.TYPE_SCHEDULE);
+				triggerInfo.setTrigger_info(info.getName()+"("+info.getId()+")");
 
-		//JobDetailに呼び出すメソッドの引数を設定
-		Object[] jdArgs = new Object[QuartzConstant.ARGS_NUM];
-		Class[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
-		//ジョブユニットIDを設定
-		jdArgs[QuartzConstant.INDEX_JOBUNIT_ID] = info.getJobunitId();
-		jdArgsType[QuartzConstant.INDEX_JOBUNIT_ID] = String.class;
+				//JobDetailに呼び出すメソッドの引数を設定
+				Object[] jdArgs = new Object[QuartzConstant.ARGS_NUM];
+				Class[] jdArgsType = new Class[QuartzConstant.ARGS_NUM];
+				//ジョブユニットIDを設定
+				jdArgs[QuartzConstant.INDEX_JOBUNIT_ID] = info.getJobunitId();
+				jdArgsType[QuartzConstant.INDEX_JOBUNIT_ID] = String.class;
 
-		//ジョブIDを設定
-		jdArgs[QuartzConstant.INDEX_JOB_ID] = info.getJobId();
-		jdArgsType[QuartzConstant.INDEX_JOB_ID] = String.class;
+				//ジョブIDを設定
+				jdArgs[QuartzConstant.INDEX_JOB_ID] = info.getJobId();
+				jdArgsType[QuartzConstant.INDEX_JOB_ID] = String.class;
 
-		//カレンダIDを設定
-		jdArgs[QuartzConstant.INDEX_CALENDAR_ID] = info.getCalendarId();
-		jdArgsType[QuartzConstant.INDEX_CALENDAR_ID] = String.class;
+				//カレンダIDを設定
+				jdArgs[QuartzConstant.INDEX_CALENDAR_ID] = info.getCalendarId();
+				jdArgsType[QuartzConstant.INDEX_CALENDAR_ID] = String.class;
 
-		//実行契機情報を設定
-		jdArgs[QuartzConstant.INDEX_TRIGGER_INFO] = triggerInfo;
-		jdArgsType[QuartzConstant.INDEX_TRIGGER_INFO] = JobTriggerInfo.class;
+				//実行契機情報を設定
+				jdArgs[QuartzConstant.INDEX_TRIGGER_INFO] = triggerInfo;
+				jdArgsType[QuartzConstant.INDEX_TRIGGER_INFO] = JobTriggerInfo.class;
 
-		//Cron表記へ変換
-		String cronString = QuartzUtil.getCronString(info.getScheduleType(),
-				info.getWeek(),info.getHour(),info.getMinute(),
-				info.getFromXminutes(),info.getEveryXminutes());
+				//Cron表記へ変換
+				String cronString = QuartzUtil.getCronString(info.getScheduleType(),
+						info.getWeek(),info.getHour(),info.getMinute(),
+						info.getFromXminutes(),info.getEveryXminutes());
 
-		m_log.trace("CronString =" + cronString);
+				m_log.trace("CronString =" + cronString);
 
-		// スケジュール定義を登録
-		SchedulerPlugin.scheduleCronJob(SchedulerType.DBMS, info.getId(), QuartzConstant.GROUP_NAME, new Date(System.currentTimeMillis() + 15 * 1000), cronString,
-				true, JobControllerBean.class.getName(), QuartzConstant.METHOD_NAME, jdArgsType, jdArgs);
-		if (! ValidConstant.typeToBoolean(info.getValid())) {
-			SchedulerPlugin.pauseJob(SchedulerType.DBMS, info.getId(), QuartzConstant.GROUP_NAME);
-		}
+				// スケジュール定義を登録
+				try {
+					SchedulerPlugin.scheduleCronJob(SchedulerType.DBMS, info.getId(), QuartzConstant.GROUP_NAME, new Date(System.currentTimeMillis() + 15 * 1000), cronString,
+							true, JobControllerBean.class.getName(), QuartzConstant.METHOD_NAME, jdArgsType, jdArgs);
+					if (! ValidConstant.typeToBoolean(info.getValid())) {
+						SchedulerPlugin.pauseJob(SchedulerType.DBMS, info.getId(), QuartzConstant.GROUP_NAME);
+					}
+				} catch (HinemosUnknown e) {
+					m_log.error(e);
+				}
+			}
+		});
+		
 	}
 	/**
 	 * DBのファイルチェック情報を変更します。<BR>
@@ -410,7 +432,7 @@ public class ModifyJobKick {
 	 * @see com.clustercontrol.jobmanagement.util.QuartzUtil#getQuartzManager()
 	 * @see com.clustercontrol.quartzmanager.ejb.session.QuartzManager#deleteSchedule(java.lang.String, java.lang.String)
 	 */
-	public void deleteSchedule(String scheduleId) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole {
+	public void deleteSchedule(final String scheduleId) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole {
 		// スケジュール定義を削除
 		m_log.debug("deleteSchedule() : id=" + scheduleId);
 
@@ -438,7 +460,16 @@ public class ModifyJobKick {
 			throw new HinemosUnknown(e.getMessage(), e);
 		}
 		//CronTriggerを削除
-		SchedulerPlugin.deleteJob(SchedulerType.DBMS, scheduleId, QuartzConstant.GROUP_NAME);
+		jtm.addCallback(new EmptyJpaTransactionCallback() {
+			@Override
+			public void postCommit() {
+				try {
+					SchedulerPlugin.deleteJob(SchedulerType.DBMS, scheduleId, QuartzConstant.GROUP_NAME);
+				} catch (HinemosUnknown e) {
+					 m_log.error(e); 
+				}
+			}
+		});
 	}
 	public void deleteFileCheck(String scheduleId) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole {
 		// ファイルチェック定義を削除
