@@ -88,7 +88,7 @@ public class JobDetailView extends CommonViewPart {
 	 * @see org.eclipse.jface.action.MenuManager
 	 * @see org.eclipse.swt.widgets.Menu
 	 */
-	protected void createContextMenu() {
+	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
 		menuManager.addMenuListener(new IMenuListener() {
@@ -114,14 +114,14 @@ public class JobDetailView extends CommonViewPart {
 	 * @see org.eclipse.jface.action.IToolBarManager
 	 * @see org.eclipse.jface.action.IMenuManager
 	 */
-	protected void fillContextMenu(IMenuManager manager) {
+	private void fillContextMenu(IMenuManager manager) {
 		//ビューのアクションのインスタンスを取得
 		IToolBarManager toolbar = this.getViewSite().getActionBars()
-		.getToolBarManager();
+				.getToolBarManager();
 		ActionContributionItem startJobAction = (ActionContributionItem) toolbar
-		.find(StartJobAction.ID);
+				.find(StartJobAction.ID);
 		ActionContributionItem stopJobAction = (ActionContributionItem) toolbar
-		.find(StopJobAction.ID);
+				.find(StopJobAction.ID);
 
 		//ポップアップメニューにアクションを追加
 		manager.add(startJobAction.getAction());
