@@ -24,6 +24,7 @@ import org.eclipse.ui.IViewActionDelegate;
 import org.eclipse.ui.IViewPart;
 
 import com.clustercontrol.jobmanagement.bean.JobTriggerTypeConstant;
+import com.clustercontrol.jobmanagement.util.JobEditStateUtil;
 import com.clustercontrol.jobmanagement.util.JobEndpointWrapper;
 import com.clustercontrol.jobmanagement.view.JobListView;
 import com.clustercontrol.util.Messages;
@@ -45,7 +46,7 @@ public class RunJobAction implements IViewActionDelegate {
 	/** アクションID */
 	public static final String ID = "com.clustercontrol.jobmanagement.view.action.RunJobAction";
 	/** ビュー */
-	protected IViewPart m_view;
+	private IViewPart m_view;
 
 	/**
 	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
@@ -78,15 +79,15 @@ public class RunJobAction implements IViewActionDelegate {
 
 		if (m_view instanceof JobListView) {
 			JobListView view = (JobListView) m_view
-			.getAdapter(JobListView.class);
+					.getAdapter(JobListView.class);
 
-			if(view.isUpdate()){
+			if(JobEditStateUtil.isEdit()){
 				// 確認ダイアログを生成
 				MessageDialog.openWarning(
 						null,
 						Messages.getString("confirmed"),
 						Messages.getString("message.job.43") + "\n" +
-						Messages.getString("message.job.44"));
+								Messages.getString("message.job.44"));
 				return;
 			}
 
