@@ -19,7 +19,6 @@ import org.eclipse.ui.IFolderLayout;
 import org.eclipse.ui.IPageLayout;
 
 import com.clustercontrol.ClusterControlPerspectiveBase;
-import com.clustercontrol.accesscontrol.view.UserListView;
 import com.clustercontrol.maintenance.view.MaintenanceListView;
 
 
@@ -45,10 +44,7 @@ public class MaintenancePerspective extends ClusterControlPerspectiveBase {
 		String editorArea = layout.getEditorArea();
 		//エディタ領域の上部percent%を占めるフォルダを作成
 		IFolderLayout top = layout.createFolder("top", IPageLayout.TOP, percent, editorArea);
-		//エディタ領域の下部(1-percent)%を占めるフォルダを作成
-		IFolderLayout bottom = layout.createFolder("bottom", IPageLayout.BOTTOM, (1-percent), editorArea);
 
 		top.addView(MaintenanceListView.ID);
-		bottom.addView(UserListView.ID);
 	}
 }
\ No newline at end of file
