@@ -66,6 +66,9 @@ public class GetStatusListTableDefine {
 	/** メッセージ。 */
 	public static final int MESSAGE = 10;
 
+	/** オーナーロール */
+	public static final int OWNER_ROLE = 11;
+
 	/** 初期表示時ソートカラム。 */
 	public static final int SORT_COLUMN_INDEX = FACILITY_ID;
 
@@ -81,14 +84,12 @@ public class GetStatusListTableDefine {
 	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
 	 * @see com.clustercontrol.monitor.bean.StatusTableDefine
 	 */
-	@SuppressWarnings("unchecked")
-	//	public ArrayList getStatusListTableDefine(Locale locale) {
-	public static ArrayList getStatusListTableDefine() {
+	public static ArrayList<TableColumnInfo> getStatusListTableDefine() {
 
 		Locale locale = Locale.getDefault();
 
 		/** テーブル情報定義配列 */
-		ArrayList tableDefine = new ArrayList();
+		ArrayList<TableColumnInfo> tableDefine = new ArrayList<TableColumnInfo>();
 
 		tableDefine.add(PRIORITY,
 				new TableColumnInfo(Messages.getString("priority", locale), TableColumnInfo.PRIORITY, 55, SWT.LEFT));
@@ -112,6 +113,8 @@ public class GetStatusListTableDefine {
 				new TableColumnInfo(Messages.getString("message.id", locale), TableColumnInfo.NONE, 90, SWT.LEFT));
 		tableDefine.add(MESSAGE,
 				new TableColumnInfo(Messages.getString("message", locale), TableColumnInfo.NONE, 200, SWT.LEFT));
+		tableDefine.add(OWNER_ROLE,
+				new TableColumnInfo(Messages.getString("owner.role.id", locale), TableColumnInfo.NONE, 130, SWT.LEFT));
 
 		return tableDefine;
 	}
