@@ -32,15 +32,16 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.TableColumn;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.monitor.action.GetEventListTableDefine;
 import com.clustercontrol.monitor.util.EventDataPropertyUtil;
 import com.clustercontrol.monitor.util.MonitorEndpointWrapper;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 import com.clustercontrol.ws.monitor.EventDataInfo;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 
@@ -86,7 +87,7 @@ public class EventInfoDialog extends CommonDialog {
 	 */
 	@Override
 	protected Point getInitialSize() {
-		return new Point(500, 600);
+		return new Point(500, 650);
 	}
 
 	/**
@@ -133,9 +134,10 @@ public class EventInfoDialog extends CommonDialog {
 		table.setLayoutData(gridData);
 
 		this.propertySheet = new PropertySheet(table);
+		this.propertySheet.setSize(170, 280);
 
 		// プロパティ取得及び設定
-		this.eventCommentProperty = null;
+		eventCommentProperty = null;
 		if (m_list != null) {
 			String monitorId = (String) m_list.get(GetEventListTableDefine.MONITOR_ID);
 			String monitorDetailId = (String) m_list.get(GetEventListTableDefine.MONITOR_DETAIL_ID);
@@ -145,7 +147,7 @@ public class EventInfoDialog extends CommonDialog {
 
 			try {
 				EventDataInfo info = MonitorEndpointWrapper.getEventInfo(monitorId, monitorDetailId, pluginId, facilityId, receiveTime.getTime());
-				this.eventCommentProperty = EventDataPropertyUtil.dto2property(info, Locale.getDefault());
+				eventCommentProperty = EventDataPropertyUtil.dto2property(info, Locale.getDefault());
 			} catch (InvalidRole_Exception e) {
 				MessageDialog.openInformation(null, Messages.getString("message"),
 						Messages.getString("message.accesscontrol.16"));
@@ -157,7 +159,7 @@ public class EventInfoDialog extends CommonDialog {
 						Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
 			}
 		}
-		this.propertySheet.setInput(this.eventCommentProperty);
+		this.propertySheet.setInput(eventCommentProperty);
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
@@ -179,11 +181,11 @@ public class EventInfoDialog extends CommonDialog {
 	 * 
 	 * @return プロパティ
 	 * 
-	 * @see com.clustercontrol.composite.PropertySheet#getInput()
+	 * @see com.clustercontrol.viewer.PropertySheet#getInput()
 	 */
 	public Property getInputData() {
-		if(this.eventCommentProperty != null){
-			Property copy = PropertyUtil.copy(this.eventCommentProperty);
+		if(eventCommentProperty != null){
+			Property copy = PropertyUtil.copy(eventCommentProperty);
 			return copy;
 		}
 		else{
