@@ -33,13 +33,13 @@ import org.eclipse.swt.widgets.Text;
 import org.eclipse.ui.PlatformUI;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.monitor.action.GetEventReportProperty;
 import com.clustercontrol.monitor.bean.OutputFormConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * 監視[イベントのダウンロード]ダイアログクラス<BR>
@@ -51,7 +51,7 @@ public class EventReportDialog extends CommonDialog {
 
 	// 後でpackするためsizeXはダミーの値。
 	private final int sizeX = 600;
-	private final int sizeY = 500;
+	private final int sizeY = 600;
 
 	/** プロパティシート。 */
 	private PropertySheet propertySheet = null;
@@ -63,19 +63,19 @@ public class EventReportDialog extends CommonDialog {
 	private static Property filterProperty = null;
 
 	/** 出力先テキスト。 */
-	protected Text m_textRedirect = null;
+	private Text m_textRedirect = null;
 
 	/** 出力先ボタン。 */
-	protected Button m_buttonRedirect = null;
+	private Button m_buttonRedirect = null;
 
 	/**
 	 * 出力形式。
 	 * @see com.clustercontrol.bean.OutputFormConstant
 	 */
-	protected int m_outputForm = OutputFormConstant.TYPE_PDF;
+	private int m_outputForm = OutputFormConstant.TYPE_PDF;
 
 	/** 出力先パス。 */
-	protected String m_redirect = null;
+	private String m_redirect = null;
 
 	/**
 	 * インスタンスを返します。
@@ -207,6 +207,7 @@ public class EventReportDialog extends CommonDialog {
 			filterProperty = new GetEventReportProperty().getProperty();
 		}
 		this.propertySheet.setInput(filterProperty);
+		this.propertySheet.expandAll();
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
