@@ -69,16 +69,16 @@ IWorkbenchPreferencePage {
 	public static final String P_EVENT_MAX = "eventMaxMessages";
 
 	private static final String MSG_ENABLE =
-		Messages.getString("autoupdate.enable");
+			Messages.getString("autoupdate.enable");
 
 	private static final String MSG_CYCLE =
-		Messages.getString("autoupdate.cycle") + " : ";
+			Messages.getString("autoupdate.cycle") + " : ";
 
 	private static final String MSG_MESSAGE =
-		Messages.getString("over.limit.message");
+			Messages.getString("over.limit.message");
 
 	private static final String MSG_MAX_EVENTS =
-		Messages.getString("number.of.display.events") + " : ";
+			Messages.getString("number.of.display.events") + " : ";
 
 
 	/**
@@ -134,7 +134,7 @@ IWorkbenchPreferencePage {
 				scopeGroup));
 		// 周期
 		IntegerFieldEditor scopeCycle =
-			new IntegerFieldEditor(P_SCOPE_UPDATE_CYCLE, MSG_CYCLE, scopeGroup);
+				new IntegerFieldEditor(P_SCOPE_UPDATE_CYCLE, MSG_CYCLE, scopeGroup);
 		scopeCycle.setValidRange(1, DataRangeConstant.SMALLINT_HIGH);
 		String[] args = {
 				Integer.toString(1),
@@ -156,7 +156,7 @@ IWorkbenchPreferencePage {
 				statusGroup));
 		// 周期
 		IntegerFieldEditor statusCycle =
-			new IntegerFieldEditor(P_STATUS_UPDATE_CYCLE, MSG_CYCLE, statusGroup);
+				new IntegerFieldEditor(P_STATUS_UPDATE_CYCLE, MSG_CYCLE, statusGroup);
 		statusCycle.setValidRange(1, DataRangeConstant.SMALLINT_HIGH);
 		statusCycle.setErrorMessage(Messages.getString("message.hinemos.8", args ));
 		this.addField(statusCycle);
@@ -175,7 +175,7 @@ IWorkbenchPreferencePage {
 				eventGroup));
 		// 周期
 		IntegerFieldEditor eventCycle =
-			new IntegerFieldEditor(P_EVENT_UPDATE_CYCLE, MSG_CYCLE, eventGroup);
+				new IntegerFieldEditor(P_EVENT_UPDATE_CYCLE, MSG_CYCLE, eventGroup);
 		eventCycle.setValidRange(1, DataRangeConstant.SMALLINT_HIGH);
 		eventCycle.setErrorMessage(Messages.getString("message.hinemos.8", args ));
 		this.addField(eventCycle);
@@ -185,7 +185,7 @@ IWorkbenchPreferencePage {
 
 		// 表示イベント数
 		IntegerFieldEditor eventMax =
-			new IntegerFieldEditor(P_EVENT_MAX, MSG_MAX_EVENTS, eventGroup);
+				new IntegerFieldEditor(P_EVENT_MAX, MSG_MAX_EVENTS, eventGroup);
 		eventMax.setValidRange(1, DataRangeConstant.MONITOR_EVENT_MAX);
 		String[] argsEvent = {
 				Integer.toString(1),
@@ -211,7 +211,7 @@ IWorkbenchPreferencePage {
 	/**
 	 * 設定内容を反映します。
 	 */
-	protected void applySetting() {
+	private void applySetting() {
 		IPreferenceStore store = this.getPreferenceStore();
 
 		// 存在するビュー全てに設定を適応する。
@@ -227,7 +227,7 @@ IWorkbenchPreferencePage {
 
 			for (int j = 0; j < pageCount; j++) {
 				ScopeView scopeView = (ScopeView) pages[j]
-				                                        .findView(ScopeView.ID);
+						.findView(ScopeView.ID);
 				if (scopeView != null) {
 					int cycle = store.getInt(P_SCOPE_UPDATE_CYCLE);
 					scopeView.setInterval(cycle);
@@ -239,7 +239,7 @@ IWorkbenchPreferencePage {
 				}
 
 				StatusView statusView = (StatusView) pages[j]
-				                                           .findView(StatusView.ID);
+						.findView(StatusView.ID);
 				if (statusView != null) {
 					int cycle = store.getInt(P_STATUS_UPDATE_CYCLE);
 					statusView.setInterval(cycle);
@@ -251,7 +251,7 @@ IWorkbenchPreferencePage {
 				}
 
 				EventView eventView = (EventView) pages[j]
-				                                        .findView(EventView.ID);
+						.findView(EventView.ID);
 				if (eventView != null) {
 					int cycle = store.getInt(P_EVENT_UPDATE_CYCLE);
 					eventView.setInterval(cycle);
