@@ -51,48 +51,51 @@ public class GetMonitorListTableDefine {
 	/** 説明。 */
 	public static final int DESCRIPTION = 3;
 
-	/** ファシリティ名(ファシリティID)。 */
-	public static final int FACILITY_NAME = 4;
+	/** ファシリティID */
+	public static final int FACILITY_ID = 4;
+
+	/** ファシリティ名 */
+	public static final int FACILITY_NAME = 5;
 
 	/** カレンダID。 */
-	public static final int CALENDAR_ID = 5;
+	public static final int CALENDAR_ID = 6;
 
 	/**
 	 * 実行間隔。
 	 * 
 	 * @see com.clustercontrol.bean.RunIntervalConstant
 	 */
-	public static final int RUN_INTERVAL = 6;
+	public static final int RUN_INTERVAL = 7;
 
 	/**
 	 * 監視有効／無効。
 	 * 
 	 * @see com.clustercontrol.bean.ValidConstant
 	 */
-	public static final int MONITOR_FLG = 7;
+	public static final int MONITOR_FLG = 8;
 
 	/**
 	 * 収集有効／無効。
 	 * 
 	 * @see com.clustercontrol.bean.ValidConstant
 	 */
-	public static final int COLLECTOR_FLG = 8;
+	public static final int COLLECTOR_FLG = 9;
 
 	/** オーナーロール */
-	public static final int OWNER_ROLE = 9;
+	public static final int OWNER_ROLE = 10;
 
 
 	/** 新規作成ユーザ。 */
-	public static final int CREATE_USER = 10;
+	public static final int CREATE_USER = 11;
 
 	/** 作成日時。 */
-	public static final int CREATE_TIME = 11;
+	public static final int CREATE_TIME = 12;
 
 	/** 最終変更ユーザ。 */
-	public static final int UPDATE_USER = 12;
+	public static final int UPDATE_USER = 13;
 
 	/** 最終変更日時。 */
-	public static final int UPDATE_TIME = 13;
+	public static final int UPDATE_TIME = 14;
 
 
 
@@ -128,7 +131,11 @@ public class GetMonitorListTableDefine {
 		tableDefine.add(DESCRIPTION,
 				new TableColumnInfo(Messages.getString("description", locale), TableColumnInfo.NONE, 200, SWT.LEFT));
 
-		// ファシリティ名(ファシリティID)
+		// ファシリティID
+		tableDefine.add(FACILITY_ID,
+				new TableColumnInfo(Messages.getString("facility.id", locale), TableColumnInfo.FACILITY, 110, SWT.LEFT));
+
+		// ファシリティ名
 		tableDefine.add(FACILITY_NAME,
 				new TableColumnInfo(Messages.getString("facility.name", locale), TableColumnInfo.FACILITY, 200, SWT.LEFT));
 
