@@ -18,16 +18,20 @@ package com.clustercontrol.notify.composite;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
+import org.eclipse.swt.events.SelectionAdapter;
+import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Text;
 
-import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
+import com.clustercontrol.composite.RoleIdListComposite;
+import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.notify.bean.NotifyTypeConstant;
+import com.clustercontrol.notify.dialog.NotifyBasicCreateDialog;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.notify.NotifyInfo;
 
@@ -47,13 +51,13 @@ import com.clustercontrol.ws.notify.NotifyInfo;
 public class NotifyBasicComposite extends Composite {
 
 	/** カラム数（タイトル）。*/
-	public static final int WIDTH_TITLE = 2;
+	public static final int WIDTH_TITLE = 3;
 
 	/** カラム数（値）。*/
 	public static final int WIDTH_VALUE = 8;
 
 	/** 空白のカラム。*/
-	public static final int WIDTH_BLANK = 5;
+	public static final int WIDTH_BLANK = 4;
 
 	/** カラム数（全て）。*/
 	public static final int WIDTH_ALL = 15;
@@ -64,11 +68,18 @@ public class NotifyBasicComposite extends Composite {
 	/** 説明 テキストボックス。 */
 	private Text m_textDescription = null;
 
+	/** オーナーロールID用テキスト */
+	protected RoleIdListComposite m_ownerRoleId = null;
+
 	/** 変更対象通知ID。 */
 	private String notifyId = null;
 
 	/** ダイアログの編集モード */
 	private int notifyIdType = 0;
+	
+	/** 親ダイアログ  */
+	protected NotifyBasicCreateDialog parentDialog = null;
+
 
 	/**
 	 * インスタンスを返します。
@@ -91,11 +102,13 @@ public class NotifyBasicComposite extends Composite {
 	}
 
 
-	public NotifyBasicComposite(Composite parent, int style, String notifyId, int notifyIdType) {
+	public NotifyBasicComposite(Composite parent, int style, String notifyId, int notifyIdType, NotifyBasicCreateDialog parentDialog) {
 		super(parent, style);
 
 		this.notifyId = notifyId;
 		this.notifyIdType = notifyIdType;
+		this.parentDialog = parentDialog;
+		
 		this.initialize();
 	}
 
@@ -142,17 +155,6 @@ public class NotifyBasicComposite extends Composite {
 			}
 		});
 
-		switch (notifyIdType) {
-		case NotifyTypeConstant.NOTIFY_ID_TYPE_TROUBLE_DETECTION :
-			this.m_textNotifyId.setText(HinemosModuleConstant.SYSYTEM_TROUBLE_DETECTION);
-			break;
-		case NotifyTypeConstant.NOTIFY_ID_TYPE_SELFCHECK :
-			this.m_textNotifyId.setText(HinemosModuleConstant.SYSYTEM_SELFCHECK);
-			break;
-		default :
-
-		}
-
 		// 空白
 		label = new Label(this, SWT.NONE);
 		gridData = new GridData();
@@ -187,6 +189,35 @@ public class NotifyBasicComposite extends Composite {
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 
+		/*
+		 * オーナーロールID
+		 */
+		Label labelRoleId = new Label(this, SWT.LEFT);
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		labelRoleId.setLayoutData(gridData);
+		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
+		if (this.parentDialog.getUpdateFlg()) {
+			this.m_ownerRoleId = new RoleIdListComposite(this, SWT.NONE, false, Mode.OWNER_ROLE);
+		} else {
+			this.m_ownerRoleId = new RoleIdListComposite(this, SWT.NONE, true, Mode.OWNER_ROLE);
+		}
+		gridData = new GridData();
+		gridData.horizontalSpan = 5;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_ownerRoleId.setLayoutData(gridData);
+		
+		if (!this.parentDialog.getUpdateFlg()) {
+			m_ownerRoleId.getComboRoleId().addSelectionListener(new SelectionAdapter() {
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					parentDialog.setOwnerRoleId(m_ownerRoleId.getText());
+				}
+			});
+		}
 	}
 
 	/**
@@ -207,17 +238,30 @@ public class NotifyBasicComposite extends Composite {
 	 * 引数で指定された通知情報の値を、各項目に設定します。
 	 * 
 	 * @param info 設定値として用いる通知情報
+	 * @param udpateFlg 更新するか否か（true：更新する）
 	 */
-	public void setInputData(NotifyInfo info) {
+	public void setInputData(NotifyInfo info, boolean updateFlg) {
 
 		if(info != null){
+			// 通知
 			if (info.getNotifyId() != null) {
 				this.m_textNotifyId.setText(info.getNotifyId());
-				this.m_textNotifyId.setEnabled(false);
+				if (updateFlg) {
+					this.m_textNotifyId.setEnabled(false);
+				}
 			}
+			// 説明
 			if (info.getDescription() != null) {
 				this.m_textDescription.setText(info.getDescription());
 			}
+			// オーナーロールID
+			if (info.getOwnerRoleId() != null) {
+				this.m_ownerRoleId.setText(info.getOwnerRoleId());
+				this.parentDialog.setOwnerRoleId(info.getOwnerRoleId());
+			} else {
+				this.parentDialog.setOwnerRoleId(m_ownerRoleId.getText());
+			}
+			
 		}
 
 		this.update();
@@ -236,15 +280,21 @@ public class NotifyBasicComposite extends Composite {
 	public ValidateResult createInputData(NotifyInfo info, String notifyId) {
 
 		if(info != null){
+			// 通知
 			if (this.m_textNotifyId.getText() != null
 					&& !"".equals((this.m_textNotifyId.getText()).trim())) {
 				info.setNotifyId(this.m_textNotifyId.getText());
 			}
-
+			// 説明
 			if (this.m_textDescription.getText() != null
 					&& !"".equals((this.m_textDescription.getText()).trim())) {
 				info.setDescription(this.m_textDescription.getText());
 			}
+			// オーナーロールID
+			if (this.m_ownerRoleId.getText() != null
+					&& !"".equals((this.m_ownerRoleId.getText()).trim())) {
+				info.setOwnerRoleId(this.m_ownerRoleId.getText());
+			}
 		}
 		return null;
 	}
@@ -280,4 +330,8 @@ public class NotifyBasicComposite extends Composite {
 
 		return validateResult;
 	}
+	
+	public RoleIdListComposite getRoleIdList(){
+		return this.m_ownerRoleId;
+	}
 }
\ No newline at end of file
