@@ -15,8 +15,6 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.notify.dialog;
 
-import java.util.ArrayList;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.dialogs.IDialogConstants;
@@ -32,7 +30,7 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Shell;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
-import com.clustercontrol.notify.bean.QueueConstant;
+import com.clustercontrol.notify.bean.NotifyTypeConstant;
 import com.clustercontrol.notify.composite.NotifyTypeListComposite;
 import com.clustercontrol.notify.util.NotifyTypeUtil;
 import com.clustercontrol.notify.view.action.NotifyModifyAction;
@@ -106,14 +104,14 @@ public class NotifyTypeDialog extends CommonDialog {
 		notifyTypeList.setLabelProvider(new LabelProvider() {
 			@Override
 			public String getText(Object element) {
-				Integer notifyType = (Integer)((ArrayList)element).get(0);
+				Integer notifyType = (Integer)element;
 				return NotifyTypeUtil.typeToString(notifyType);
 			}
 		});
 
 		// 通知タイプ定義のインスタンスを登録する
-		for (ArrayList<Object> list : QueueConstant.getQueueList()) {
-			notifyTypeList.add(list);
+		for (Integer type : NotifyTypeConstant.getList()) {
+			notifyTypeList.add(type);
 		}
 
 		// アイテムをダブルクリックした場合、それを選択したこととする。
@@ -129,7 +127,7 @@ public class NotifyTypeDialog extends CommonDialog {
 		shell.setSize(new Point(shell.getSize().x, shell.getSize().y));
 	}
 
-	public ArrayList<Object> getSelectItem() {
+	public Integer getSelectItem() {
 		return this.listComposite.getSelectItem();
 	}
 
@@ -147,10 +145,10 @@ public class NotifyTypeDialog extends CommonDialog {
 		}
 
 		// DBに登録されているダイアログのクラス名を取得する
-		Integer notifyType = (Integer)((ArrayList)this.getSelectItem()).get(0);
+		Integer notifyType = this.getSelectItem();
 		NotifyModifyAction action = new NotifyModifyAction();
 		if (action.openDialog(getParentShell(), null, notifyType) ==
-			IDialogConstants.OK_ID) {
+				IDialogConstants.OK_ID) {
 			composite.update();
 		}
 
