@@ -90,6 +90,18 @@ public class NotifyDispatcher {
 			return;
 		}
 
+		// 監視詳細を空文字にする。(抑制の粒度を変更したい場合に利用する。)
+		String pluginId = info.getPluginId();
+		String key = "notify.remove.subkey." + pluginId;
+		try { 
+			boolean flag = Boolean.parseBoolean(HinemosProperties.getProperty(key, "false"));
+			if (flag) {
+				info.setSubKey("");
+			}
+		} catch (Exception e) {
+			m_log.info(key + " : " + e.getMessage());
+		}
+		
 		// 監視結果重要度ステータスを更新
 		boolean prioityChangeFlag = MonitorResultStatusUpdater.update(info);
 
