@@ -321,11 +321,13 @@ public class SendMail implements Notifier {
 			} catch (SMTPAddressFailedException e) {
 				throw e;
 			} catch (MessagingException me) {
-				if (i < _transportTries) {
+				//_transportTries中はsleep待ちのみ
+				if (i < (_transportTries - 1)) {
 					m_log.info("sendMail() : retry sendmail. " + me.getMessage());
 					try {
 						Thread.sleep(_transportTriesInterval);
 					} catch (InterruptedException e) { }
+				//_transportTriesの最後はINTERNALイベントの通知のためExceptionをthrow
 				} else {
 					throw me;
 				}
