@@ -28,27 +28,23 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.fault.NotifyNotFound;
 import com.clustercontrol.notify.bean.ExecFacilityConstant;
 import com.clustercontrol.notify.bean.NotifyRequestMessage;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
 import com.clustercontrol.notify.bean.SyslogFacilityConstant;
 import com.clustercontrol.notify.bean.SyslogSeverityConstant;
-import com.clustercontrol.notify.ejb.entity.NotifyLogEscalateInfoData;
-import com.clustercontrol.notify.ejb.entity.NotifyLogEscalateInfoLocal;
-import com.clustercontrol.notify.ejb.entity.NotifyLogEscalateInfoPK;
-import com.clustercontrol.notify.ejb.entity.NotifyLogEscalateInfoUtil;
+import com.clustercontrol.notify.model.NotifyLogEscalateInfoEntity;
+import com.clustercontrol.notify.entity.NotifyLogEscalateInfoData;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
-import com.clustercontrol.repository.ejb.entity.FacilityLocal;
-import com.clustercontrol.repository.ejb.entity.FacilityUtil;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
+import com.clustercontrol.repository.model.FacilityEntity;
+import com.clustercontrol.repository.session.RepositoryControllerBean;
+import com.clustercontrol.repository.util.FacilityUtil;
 import com.clustercontrol.util.StringBinder;
 import com.clustercontrol.util.apllog.AplLogger;
 
@@ -88,10 +84,10 @@ public class SendSyslog implements Notifier {
 			} else if ("".equals(hostname)) {
 				// invalid hostname of syslog header
 				MODE_HOSTNAME = MODE_HOSTNAME_DEFAULT;
-			} else if ("${FACILITY_ID}".equals(hostname)) {
+			} else if ("#[FACILITY_ID]".equals(hostname)) {
 				// use facility_id as hostname of syslog header
 				MODE_HOSTNAME = MODE_HOSTNAME_FACILITYID;
-			} else if ("${NODE}".equals(hostname)) {
+			} else if ("#[NODE]".equals(hostname)) {
 				// use nodename as hostname of syslog header
 				MODE_HOSTNAME = MODE_HOSTNAME_NODENAME;
 			} else {
@@ -101,21 +97,17 @@ public class SendSyslog implements Notifier {
 
 			HOSTNAME_SERVER = InetAddress.getLocalHost().getHostName();
 
-			m_log.info("initialized syslog sender. (mode = " + MODE_HOSTNAME + ", hostname=" + HOSTNAME_DEFINED + ")");
+			m_log.info("static()initialized syslog sender. (mode = " + MODE_HOSTNAME + ", hostname=" + HOSTNAME_DEFINED + ")");
 
 		} catch (Exception e) {
-			m_log.warn(e.getMessage(), e);
+			m_log.warn("static() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 	}
 
-	/**
-	 * ログエスカレーション通知：
-	 * NotifyLogEscalationBean.onMessage()より呼び出す通知処理
-	 * 
-	 */
 	@Override
 	public void notify(NotifyRequestMessage message)
-	throws FinderException, NamingException {
+			throws NotifyNotFound {
 		if(m_log.isDebugEnabled()){
 			m_log.debug("notify() " + message);
 		}
@@ -128,23 +120,31 @@ public class SendSyslog implements Notifier {
 	 * 
 	 * @param outputInfo
 	 * @param notifyId
-	 * @throws FinderException
-	 * @throws NamingException
+	 * @throws NotifyNotFound
 	 */
 	private void sendlog(OutputBasicInfo outputInfo, String notifyId)
-	throws FinderException, NamingException {
+			throws NotifyNotFound {
 		if(m_log.isDebugEnabled()){
 			m_log.debug("sendlog() " + outputInfo);
 		}
-
 		// 該当する重要度の通知情報を取得する
-		NotifyLogEscalateInfoLocal logEscalateInfo = NotifyLogEscalateInfoUtil.getLocalHome().findByPrimaryKey(
-				new NotifyLogEscalateInfoPK(notifyId, outputInfo.getPriority()));
+		NotifyLogEscalateInfoEntity logEscalateInfo
+		= QueryUtil.getNotifyLogEscalateInfoPK(notifyId, outputInfo.getPriority());
 
-		NotifyLogEscalateInfoData escalateInfoData = logEscalateInfo.getData();
+		NotifyLogEscalateInfoData escalateInfoData = new NotifyLogEscalateInfoData();
+		escalateInfoData.setNotifyId(logEscalateInfo.getId().getNotifyId());
+		escalateInfoData.setPriority(logEscalateInfo.getId().getPriority());
+		escalateInfoData.setValidFlg(logEscalateInfo.getEscalateFlg());
+		escalateInfoData.setEscalateMessage(logEscalateInfo.getEscalateMessage());
+		escalateInfoData.setSyslogPriority(logEscalateInfo.getSyslogPriority());
+		escalateInfoData.setSyslogFacility(logEscalateInfo.getSyslogFacility());
+		escalateInfoData.setEscalateFacilityFlg(logEscalateInfo.getEscalateFacilityFlg());
+		escalateInfoData.setEscalateFacility(logEscalateInfo.getEscalateFacilityId());
+		escalateInfoData.setEscalatePort(logEscalateInfo.getEscalatePort() );
+		escalateInfoData.setOwnerRoleId(logEscalateInfo.getNotifyInfoEntity().getOwnerRoleId());
 
 		// syslogの本文を作成
-		String message = getMessage(outputInfo, escalateInfoData);
+		String message = getMessage(outputInfo, logEscalateInfo);
 
 		/**
 		 * 実行
@@ -152,7 +152,7 @@ public class SendSyslog implements Notifier {
 		List<InetAddress> ipAddresses = getIpAddresses(outputInfo, escalateInfoData);
 		if(ipAddresses == null){
 			String detailMsg = "IP Address is empty.";
-			m_log.error(detailMsg);
+			m_log.info(detailMsg);
 			internalErrorNotify(notifyId, "007", detailMsg);
 		}
 
@@ -171,7 +171,8 @@ public class SendSyslog implements Notifier {
 				this.sendAfterConvertHostname(escalateInfoData, address, outputInfo.getFacilityId(), message, headerTimeStamp);
 			} catch (IOException e) {
 				String detailMsg = e.getMessage() + " IP Address = " + address;
-				m_log.error("sendlog():" + detailMsg, e);
+				m_log.info("sendlog() " + detailMsg + " : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage());
 				internalErrorNotify(notifyId, "007", detailMsg);
 				// 続けて次のIPを処理する
 			}
@@ -188,12 +189,11 @@ public class SendSyslog implements Notifier {
 	 * @return 送信先ノードのIPアドレス
 	 */
 	private List<InetAddress> getIpAddresses(OutputBasicInfo outputInfo, NotifyLogEscalateInfoData logEscalateInfo){
+
 		// 送信先を特定
 		ArrayList<InetAddress> ipAddresses = new ArrayList<InetAddress>();
 		//リポジトリ(RepositoryControllerLocal)を取得
 		try {
-			RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
-
 			String facilityId = null;
 
 			// 固定スコープ
@@ -211,57 +211,64 @@ public class SendSyslog implements Notifier {
 				}
 			}
 
-			ArrayList<String> facilityIdList = repository.getExecTargetFacilityIdList(facilityId);
+			ArrayList<String> facilityIdList = new RepositoryControllerBean().getExecTargetFacilityIdList(facilityId, logEscalateInfo.getOwnerRoleId());
 
 			for(String targetFacilityId : facilityIdList){
-				FacilityLocal facility = FacilityUtil.getLocalHome().findByPrimaryKey(targetFacilityId);
+				FacilityEntity facility
+				= new RepositoryControllerBean().getFacilityEntityByPK(targetFacilityId);
 				try {
 					ipAddresses.add(getInetAdress(facility));
 				} catch (UnknownHostException e) {
-					m_log.error(e.getMessage(), e);
+					m_log.info("getIpAddresses() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage());
 					// 続けて次のノードを処理する
 				}
 			}
 
 			return ipAddresses;
 		} catch (Exception e) {
-			m_log.error(e.getMessage(), e);
+			m_log.warn("getIpAddresses() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			// 例外が発生した場合は、空のリストを返す
 			return null;
 		}
 	}
 
 	// 文字列を置換する
-	private String getMessage(OutputBasicInfo outputInfo, NotifyLogEscalateInfoData logEscalateInfo){
+	private String getMessage(OutputBasicInfo outputInfo, NotifyLogEscalateInfoEntity logEscalateInfo){
 		// 文字列を置換する
 		try {
-			Map<String, String> param = NotifyUtil.createParameter(outputInfo);
+			Map<String, String> param = NotifyUtil.createParameter(outputInfo,
+					logEscalateInfo.getNotifyInfoEntity());
 			StringBinder binder = new StringBinder(param);
 			return binder.bindParam(logEscalateInfo.getEscalateMessage());
 		} catch (Exception e) {
-			m_log.error(e.getMessage(), e);
-
+			m_log.warn("getMessage() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			// 例外が発生した場合は、置換前の文字列を返す
 			return logEscalateInfo.getEscalateMessage();
 		}
 	}
 
-	private InetAddress getInetAdress(FacilityLocal facility) throws UnknownHostException{
+	private InetAddress getInetAdress(FacilityEntity facility) throws UnknownHostException {
 		InetAddress ret = null;
 
 		// IPアドレスの取得
 		int version = 4;
-		if(facility.getNode().getIpAddressVersion() != null){
-			version = facility.getNode().getIpAddressVersion();
+		if(facility.getNodeEntity() != null
+				&& facility.getNodeEntity().getIpAddressVersion() != null){
+			version = facility.getNodeEntity().getIpAddressVersion();
 		}else{
 			version = 4;
 		}
 		// 入力されているバージョンを比較し、対応するIPアドレスを取得する
 		if(version == 4) {
-			ret = InetAddress.getByName(facility.getNode().getIpAddressV4());
+			ret = InetAddress.getByName(
+					facility.getNodeEntity() == null ? null : facility.getNodeEntity().getIpAddressV4());
 		}
 		else {
-			ret = InetAddress.getByName(facility.getNode().getIpAddressV6());
+			ret = InetAddress.getByName(
+					facility.getNodeEntity() == null ? null : facility.getNodeEntity().getIpAddressV6());
 		}
 
 		return ret;
@@ -277,28 +284,7 @@ public class SendSyslog implements Notifier {
 	 * @param severity
 	 * @param facilityId
 	 * @param message
-	 */
-	public void sendAfterConvertHostname(String ipAddress, int port, String facility, String severity, String facilityId, String message) {
-		// ローカル変数
-		String hostname = "";
-
-		// メイン処理
-		SimpleDateFormat sdf = new SimpleDateFormat(SendSyslog.HEADER_DATE_FORMAT, Locale.US);
-		String timeStamp = sdf.format(new Date());
-		hostname = getSyslogHeaderHost(facilityId);
-		sendAfterConvertHostname(ipAddress, port, facility, severity, hostname, message, timeStamp);
-	}
-	
-	/**
-	 * 汎用syslog送信処理(ShelfCheckTask、AplLogger)：
-	 * 設定ファイルに従ってホスト名をヘッダに埋め込み、syslogパケットを送信する。<br>
-	 * 
-	 * @param ipAddress
-	 * @param port
-	 * @param facility
-	 * @param severity
-	 * @param facilityId
-	 * @param message
+	 * @param timeStamp
 	 */
 	public void sendAfterConvertHostname(String ipAddress, int port, String facility, String severity, String facilityId, String message, String timeStamp) {
 		// ローカル変数
@@ -347,7 +333,7 @@ public class SendSyslog implements Notifier {
 			facilityInt = SyslogFacilityConstant.stringToType(facility);
 			severityInt = SyslogSeverityConstant.stringToType(severity);
 			if (facilityInt == -1 || severityInt == -1) {
-				m_log.warn("sending syslog failure. facility(" + facility + ") or severity(" + severity + ") is invalid.");
+				m_log.info("send() sending syslog failure. facility(" + facility + ") or severity(" + severity + ") is invalid.");
 				return;
 			}
 			priority = facilityInt + severityInt;
@@ -373,11 +359,14 @@ public class SendSyslog implements Notifier {
 			soc.close();
 
 		} catch (UnknownHostException e) {
-			m_log.warn("sending syslog failure. syslog's host(" + ipAddress + ") is invalid.", e);
+			m_log.info("sending syslog failure. syslog's host(" + ipAddress + ") is invalid."
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 		} catch (SocketException e) {
-			m_log.warn("sending syslog failure.", e);
+			m_log.info("sending syslog failure."
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 		} catch (IOException e) {
-			m_log.warn("sending syslog failure.", e);
+			m_log.info("sending syslog failure."
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 		}
 
 		if (m_log.isDebugEnabled())
@@ -391,13 +380,14 @@ public class SendSyslog implements Notifier {
 	 * @return
 	 */
 	private static String getSyslogHeaderHost(String facilityId) {
+		JpaTransactionManager jtm = null;
 		// ローカル変数
 		String hostname = "";
 		int mode = MODE_HOSTNAME;
 		boolean isBuildinScope = false;
 
 		// メイン処理
-		if (m_log.isDebugEnabled()) m_log.debug("converting syglog hostname for '" + facilityId + "'. (mode = " + MODE_HOSTNAME + ")");
+		if (m_log.isDebugEnabled()) m_log.debug("converting syslog hostname for '" + facilityId + "'. (mode = " + MODE_HOSTNAME + ")");
 
 		if (FacilityTreeAttributeConstant.isBuiltinScope(facilityId)) {
 			// 組み込みスコープの場合は、マネージャのホスト名を埋め込む
@@ -414,16 +404,26 @@ public class SendSyslog implements Notifier {
 			break;
 		case MODE_HOSTNAME_NODENAME :
 			try {
-				FacilityLocal facility = FacilityUtil.getLocalHome().findByPrimaryKey(facilityId);
-				if (facility.isNode()) {
-					hostname = isBuildinScope ? HOSTNAME_SERVER : facility.getNode().getNodeName();
+				jtm = new JpaTransactionManager();
+				jtm.begin();
+
+				FacilityEntity facility
+				= new RepositoryControllerBean().getFacilityEntityByPK(facilityId);
+				if (FacilityUtil.isNode(facility)) {
+					hostname = isBuildinScope ? HOSTNAME_SERVER :
+						(facility.getNodeEntity() == null ? null : facility.getNodeEntity().getNodeName());
 				} else {
 					if (m_log.isDebugEnabled()) m_log.debug("facility '" + facilityId + "' is not node.");
 					hostname = HOSTNAME_SERVER;
 				}
+				jtm.commit();
 			} catch (Exception e) {
 				hostname = HOSTNAME_SERVER;
-				m_log.warn("use '" + hostname + "' for hostname of syslog header. (facility not found : " + facilityId + ")");
+				m_log.warn("getSyslogHeaderHost() use '" + hostname + "' for hostname of syslog header. (facility not found : " + facilityId + ") : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+				jtm.rollback();
+			} finally {
+				jtm.close();
 			}
 			break;
 		default :
@@ -459,8 +459,6 @@ public class SendSyslog implements Notifier {
 	 * 
 	 * @param logEscalateInfo	通知内容
 	 * @param ipAddress	IPアドレス
-	 * @throws FinderException
-	 * @throws NamingException
 	 * @throws IOException
 	 */
 	private void send(NotifyLogEscalateInfoData logEscalateInfo, InetAddress ipAddress, String hostname, String message,String headerTimeStamp) throws IOException {
