@@ -1303,11 +1303,7 @@ public class PerformanceGraphComposite extends Composite {
 			break;
 
 		case GraphConstant.DISPLAY_ITEMCODE:
-			if(targetItemCodeInfo.getDisplayName() != null && !"".equals(targetItemCodeInfo.getDisplayName())){
-				title = PerformanceDataSettingsUtil.getItemName(performanceDataSettings, targetItemCodeInfo.getItemCode()) + "[" + targetItemCodeInfo.getDisplayName() + "]";
-			}else{
-				title = PerformanceDataSettingsUtil.getItemName(performanceDataSettings, targetItemCodeInfo.getItemCode());
-			}
+			title = PerformanceDataSettingsUtil.getItemName(performanceDataSettings, targetItemCodeInfo.getItemCode());
 			title = title + " " + STRING_DISPLAY_ITEMCODE;
 			break;
 
@@ -1346,7 +1342,17 @@ public class PerformanceGraphComposite extends Composite {
 			return new ArrayList<CollectedDataInfo>();
 		}
 
-
+		// 空 Check
+		if(dataSet1.size() == 0 && dataSet2.size() > 0){
+			return dataSet2;
+		}
+		if(dataSet2.size() == 0 && dataSet1.size() > 0){
+			return dataSet1;
+		}
+		if(dataSet1.size() == 0 && dataSet2.size() == 0){
+			return new ArrayList<CollectedDataInfo>();
+		}
+		
 		ArrayList<CollectedDataInfo> dataList = new ArrayList<CollectedDataInfo>();
 
 		// 時刻がずれている場合は、別時刻の収集値であるため加算しない
