@@ -21,40 +21,31 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
-import javax.ejb.CreateException;
-import javax.ejb.EJBException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.bean.YesNoConstant;
+import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.performance.bean.CollectorItemInfo;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryCollectMstLocal;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryCollectMstUtil;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryMstData;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryMstLocal;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryMstUtil;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorItemCalcMethodMstLocal;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorItemCalcMethodMstUtil;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorItemCodeMstData;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorItemCodeMstLocal;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorItemCodeMstUtil;
+import com.clustercontrol.performance.factory.OperateCollectCategoryMaster;
+import com.clustercontrol.performance.factory.OperateCollectItemCodeMaster;
+import com.clustercontrol.performance.monitor.entity.CollectorCategoryMstData;
+import com.clustercontrol.performance.monitor.entity.CollectorItemCodeMstData;
+import com.clustercontrol.performance.monitor.model.CollectorCategoryCollectMstEntity;
+import com.clustercontrol.performance.monitor.model.CollectorItemCalcMethodMstEntity;
 import com.clustercontrol.performance.util.CollectorMasterCache;
 import com.clustercontrol.performance.util.PollingDataManager;
+import com.clustercontrol.performance.monitor.util.QueryUtil;
 import com.clustercontrol.repository.bean.NodeDeviceInfo;
 import com.clustercontrol.repository.bean.NodeInfo;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 import com.clustercontrol.repository.factory.FacilitySelector;
 import com.clustercontrol.repository.factory.NodeProperty;
+import com.clustercontrol.repository.session.RepositoryControllerBean;
 
 /**
  * 収集項目コードの情報を生成するファクトリクラス
@@ -72,91 +63,76 @@ public class CollectorItemCodeTable {
 	static {
 		m_codeTable = new HashMap<String, CollectorItemTreeItem>(); // 収集項目コードがキー
 
-		// カテゴリコードからカテゴリ情報を参照するためのテーブル
-		HashMap<String, CollectorItemTreeItem> categoryTable =
-			new HashMap<String, CollectorItemTreeItem>();
-
-		// カテゴリ情報の読み込み
-		Collection<CollectorCategoryMstLocal> cate = null;
-		try {
-			cate = CollectorCategoryMstUtil.getLocalHome().findAll();
-		} catch (FinderException e) {
-			m_log.error(e.getMessage(), e);
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(), e);
-		}
-
-		Iterator<CollectorCategoryMstLocal> cateItr = cate.iterator();
-		while(cateItr.hasNext()){
-			CollectorCategoryMstLocal bean = cateItr.next();
-
-			CollectorCategoryMstData category  =
-				new CollectorCategoryMstData(bean.getCategoryCode(), bean.getCategoryName());
-
-			CollectorItemTreeItem categoryItem =
-				new CollectorItemTreeItem(null, null, category, null, null);  // 親の要素はないためnull
-
-			// カテゴリコードにマッピングするようにカテゴリ情報を登録
-			categoryTable.put(bean.getCategoryCode(), categoryItem);
-		}
-
-
-
-		try {
-			// 収集項目コードの読み込み
-			Collection<CollectorItemCodeMstLocal> ctItemCodeMst = CollectorItemCodeMstUtil.getLocalHome().findAll();
-
-			Iterator<CollectorItemCodeMstLocal> itrItemCode = ctItemCodeMst.iterator();
-
-			while(itrItemCode.hasNext()) {
-				CollectorItemCodeMstLocal codeBean = itrItemCode.next();
-				String itemCode = codeBean.getItemCode();
-
-				if(itemCode == null){
-					continue;
-				}
-
-				if(itemCode != null && codeBean.getCategoryCode() != null
-						&& codeBean.getDeviceSupport() != null && codeBean.getGraphRange() != null){
-
-					// 収集項目コードマスタ情報のDTOを作成
-					CollectorItemCodeMstData codeData = new CollectorItemCodeMstData(
-							codeBean.getItemCode(),
-							codeBean.getCategoryCode(),
-							codeBean.getParentItemCode(),
-							codeBean.getItemName(),
-							codeBean.getMeasure(),
-							codeBean.getDeviceSupport(),
-							codeBean.getDeviceType(),
-							codeBean.getGraphRange()
-					);
-
-					// カテゴリ名を調べます
-					CollectorItemTreeItem categoryTreeItem = categoryTable.get(codeBean.getCategoryCode());
-
-					// 親のオブジェクトを取得（存在しない場合はnull）
-					CollectorItemTreeItem parentItem =
-						m_codeTable.get(codeBean.getParentItemCode());
-
-					// 親のコードが存在しない場合はカテゴリの直下の要素とする
-					if(parentItem == null){
-						parentItem = categoryTreeItem;
+		JpaTransactionManager jtm = new JpaTransactionManager();
+		if (!jtm.isNestedEm()) {
+			m_log.warn("refresh() : transactioin has not been begined.");
+			jtm.close();
+		} else {
+	
+			// カテゴリコードからカテゴリ情報を参照するためのテーブル
+			HashMap<String, CollectorItemTreeItem> categoryTable =
+					new HashMap<String, CollectorItemTreeItem>();
+	
+			// カテゴリ情報の読み込み
+			Collection<CollectorCategoryMstData> cate = null;
+			try {
+				cate = new OperateCollectCategoryMaster().findAll();
+			} catch (Exception e) {
+				m_log.warn("static() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+			}
+	
+			for(CollectorCategoryMstData category : cate) {
+				CollectorItemTreeItem categoryItem =
+						new CollectorItemTreeItem(null, null, category, null, null);  // 親の要素はないためnull
+	
+				// カテゴリコードにマッピングするようにカテゴリ情報を登録
+				categoryTable.put(category.getCategoryCode(), categoryItem);
+			}
+	
+	
+	
+			try {
+				// 収集項目コードの読み込み
+				Collection<CollectorItemCodeMstData> ctItemCodeMst
+				= new OperateCollectItemCodeMaster().findAll();
+	
+				for (CollectorItemCodeMstData codeData : ctItemCodeMst) {
+					String itemCode = codeData.getItemCode();
+	
+					if(itemCode == null){
+						continue;
+					}
+	
+					if(itemCode != null && codeData.getCategoryCode() != null
+							&& codeData.getDeviceSupport() != null && codeData.getGraphRange() != null){
+	
+						// カテゴリ名を調べます
+						CollectorItemTreeItem categoryTreeItem = categoryTable.get(codeData.getCategoryCode());
+	
+						// 親のオブジェクトを取得（存在しない場合はnull）
+						CollectorItemTreeItem parentItem =
+								m_codeTable.get(codeData.getParentItemCode());
+	
+						// 親のコードが存在しない場合はカテゴリの直下の要素とする
+						if(parentItem == null){
+							parentItem = categoryTreeItem;
+						}
+	
+						CollectorItemTreeItem ctItem =
+								new CollectorItemTreeItem(parentItem, codeData, null, null, null);
+	
+						// 収集項目コードをキーとして登録
+						m_codeTable.put(itemCode, ctItem);
 					}
-
-					CollectorItemTreeItem ctItem =
-						new CollectorItemTreeItem(parentItem, codeData, null, null, null);
-
-					// 収集項目コードをキーとして登録
-					m_codeTable.put(itemCode, ctItem);
 				}
+	
+			} catch (Exception e) {
+				m_codeTable.clear();
+				// エラー処理
+				m_log.warn("CollectorItemCodeTable static field error . ", e);
 			}
-
-		} catch (Exception e) {
-			m_codeTable.clear();
-			// エラー処理
-			m_log.warn("CollectorItemCodeTable static field error . ", e);
 		}
-
 	}
 
 	/**
@@ -227,24 +203,23 @@ public class CollectorItemCodeTable {
 	 * 
 	 * @param facilityId
 	 * @return
+	 * @throws HinemosUnknown
 	 */
-	private static Set<CollectorItemCodeMstData> getEnableCodeSet(String facilityId){
+	private static Set<CollectorItemCodeMstData> getEnableCodeSet(String facilityId) throws HinemosUnknown{
 		m_log.debug("getEnableCodeSet() facilityId = " + facilityId);
 
-		// 選択可能な収集項目コード情報のセット
-		Set<CollectorItemCodeMstData> codeSet = null;
+		// 対象ファシリティIDに含まれる全ノードに対して選択可能な収集項目コードのセット（本関数で返すべき結果）
+		Set<CollectorItemCodeMstData> enableItemCodeSetInEveryNode = null;
 
-		// 対象ファシリティIDが空またはNULLなら
+		// 対象ファシリティIDが空またはNULLなら何も選択できるものはない
 		if(facilityId == null || "".equals(facilityId)){
 			m_log.debug("getEnableCodeSet() codeSet is 0");
-			return codeSet;
+			return enableItemCodeSetInEveryNode;
 		}
 
-		// 全てのノードのプラットフォームIDのセット
-		Set<PlatformIdAndSubPlatformId> platformSet = new HashSet<PlatformIdAndSubPlatformId>();
 		try {
 			// リポジトリ管理機能のSessionBean
-			RepositoryControllerLocal bean = RepositoryControllerUtil.getLocalHome().create();
+			RepositoryControllerBean bean = new RepositoryControllerBean();
 
 			////
 			// 探査対象となるノードリストを作成
@@ -260,80 +235,99 @@ public class CollectorItemCodeTable {
 				m_log.debug("getEnableCodeSet() facilityId is scope");
 
 				// スコープにふくまれるノードのIDのリストを取得
-				nodeList = bean.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
+				nodeList = bean.getNodeFacilityIdList(facilityId, null, RepositoryControllerBean.ALL);
 			}
 
 			////
-			// 存在する全てのプラットフォーム情報を取得
+			// 対象ファシリティ配下の全ノードが持つ全てのプラットフォームIDのセットを作る
 			////
+			Set<PlatformIdAndSubPlatformId> platformSet = new HashSet<PlatformIdAndSubPlatformId>();
 			for(String nodeId : nodeList){
 				m_log.debug("getEnableCodeSet() target node  = " + nodeId);
 				NodeInfo node = bean.getNode(nodeId);
 
-				if ("controller".equals(node.getVirtualizationNodeType())) {
-					platformSet.add(new PlatformIdAndSubPlatformId(node.getPlatformFamily(), ""));
-				} else {
-					platformSet.add(new PlatformIdAndSubPlatformId(node.getPlatformFamily(), node.getVirtualizationSolution()));
-				}
+				platformSet.add(new PlatformIdAndSubPlatformId(node.getPlatformFamily(), node.getSubPlatformFamily()));
 			}
 
 			////
-			// プラットフォームで共通の収集項目IDを取得する
+			// 各プラットフォームごとに、収集可能な収集項目IDを取得する
 			////
 			for(PlatformIdAndSubPlatformId platform : platformSet){
 
-				m_log.debug("getEnableCodeSet() " +
-						"platformId = " + platform.getPlatformId() +
-						", subPlatformId = " + platform.getSubPlatformId());
+				if (m_log.isDebugEnabled()) {
+					m_log.debug("getEnableCodeSet() " +
+							"platformId = " + platform.getPlatformId() +
+							", subPlatformId = " + platform.getSubPlatformId());
+				}
 
 				// プラットフォーム、サブプラットフォーム単位のカテゴリコード、収集方法を取得
-				Collection<CollectorCategoryCollectMstLocal> collects;
+				Collection<CollectorCategoryCollectMstEntity> collects;
 				// プラットフォーム、サブプラットフォーム単位の収集方法、アイテムコード、算出方法を取得
-				Collection<CollectorItemCalcMethodMstLocal> calsMethods;
+				List<CollectorItemCalcMethodMstEntity> calsMethods;
 				try {
-					collects = CollectorCategoryCollectMstUtil.getLocalHome().findByPlatformIdAndSubPlatformId(
+					collects = QueryUtil.getCollectorCategoryCollectMstByPlatformIdSubPlatformId(
 							platform.getPlatformId(),
 							platform.getSubPlatformId());
-
-					calsMethods = CollectorItemCalcMethodMstUtil.getLocalHome().findByPlatformIdAndSubPlatformId(
+					calsMethods = QueryUtil.getCollectorItemCalcMethodMstByPlatformIdSubPlatformId(
 							platform.getPlatformId(),
 							platform.getSubPlatformId());
-				} catch (FinderException e) {
-					m_log.error("getEnableCodeSet()", e);
-					return null;
-				} catch (NamingException e) {
-					m_log.error("getEnableCodeSet()", e);
+					if (m_log.isDebugEnabled()) {
+						m_log.debug("getEnableCodeSet() " + "platformId = " + platform.getPlatformId() + 
+								", subPlatformId = " + platform.getSubPlatformId() +
+								", CollectorCategoryCollectMstEntity size = " + collects.size() +
+								", CollectorItemCalcMethodMstEntity size = " + calsMethods.size());
+					}
+					// VM管理やクラウド管理などサブプラットフォームがある場合には、サブプラットフォームが空（つまり物理と同じ）項目を監視できるようにする
+					// 以下、サブプラットフォームが空の場合のカテゴリ＋収集方法、収集方法＋アイテムコード＋算出方法 を出し、上記のものと足し合わせる
+					if (!platform.getSubPlatformId().isEmpty()) {
+						Collection<CollectorCategoryCollectMstEntity> physicalCollects =
+								QueryUtil.getCollectorCategoryCollectMstByPlatformIdSubPlatformId(
+										platform.getPlatformId(), "");
+						Collection<CollectorItemCalcMethodMstEntity> physicalCalsMethods =
+								QueryUtil.getCollectorItemCalcMethodMstByPlatformIdSubPlatformId(
+										platform.getPlatformId(), "");
+						collects.addAll(physicalCollects);
+						calsMethods.addAll(physicalCalsMethods);
+						if (m_log.isDebugEnabled()) {
+							m_log.debug("getEnableCodeSet() " + "platformId = " + platform.getPlatformId() + 
+									", physical platform, " +
+									", CollectorCategoryCollectMstEntity size = " + physicalCollects.size() +
+									", CollectorItemCalcMethodMstEntity size = " + physicalCalsMethods.size());
+						}
+					}
+				} catch (Exception e) {
+					m_log.warn("getEnableCodeSet() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 					return null;
 				}
 
 				// categoryCodeをキーにcollectMethodを取得するマップ
 				HashMap<String, String> categoryMap = new HashMap<String, String>();
-				for(CollectorCategoryCollectMstLocal collect : collects){
-					m_log.debug("getEnableCodeSet() add map categoryCode = " + collect.getCategoryCode() + ", collectMethod = " + collect.getCollectMethod());
-					categoryMap.put(collect.getCategoryCode(), collect.getCollectMethod());
+				for(CollectorCategoryCollectMstEntity collect : collects){
+					m_log.debug("getEnableCodeSet() add map categoryCode = " + collect.getId().getCategoryCode() + ", collectMethod = " + collect.getCollectMethod());
+					categoryMap.put(collect.getId().getCategoryCode(), collect.getCollectMethod());
 				}
 
-				// プラットフォームごとに収集可能な収集項目コードのリストを求める
-				HashSet<CollectorItemCodeMstData> tmpByPlatform = new HashSet<CollectorItemCodeMstData>();
+				// このプラットフォーム・サブプラットフォームにおいて収集可能な収集項目コードを格納するSet
+				HashSet<CollectorItemCodeMstData> enableItemCodeSetByPlatform = new HashSet<CollectorItemCodeMstData>();
 
-				// 計算方法管理テーブルの要素ごとにループをまわす
-				for(CollectorItemCalcMethodMstLocal calcBean : calsMethods){
+				// 計算方法管理テーブルの各要素ごとに、その要素がこのプラットフォーム・サブプラットフォームにおいて収集可能な項目かを調べる
+				for(CollectorItemCalcMethodMstEntity calcBean : calsMethods){
 
 					CollectorItemCodeMstData codeBean;
 					try {
-						m_log.debug("getEnableCodeSet() search itemCode = " + calcBean.getItemCode());
-						codeBean = CollectorMasterCache.getCategoryCodeMst(calcBean.getItemCode());
-					} catch (FinderException e) {
-						m_log.error(e.getMessage(), e);
-						return null;
-					} catch (NamingException e) {
-						m_log.error(e.getMessage(), e);
+						m_log.debug("getEnableCodeSet() search itemCode = " + calcBean.getId().getItemCode());
+						codeBean = CollectorMasterCache.getCategoryCodeMst(calcBean.getId().getItemCode());
+					} catch (Exception e) {
+						m_log.warn("getEnableCodeSet() : "
+								+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 						return null;
 					}
 
-					// カテゴリ別収集情報の収集方法と収集項目マスタの収集方法を比較し、同じならば追加する
+					// カテゴリ別収集情報の収集方法と収集項目マスタの収集方法を比較し、同じならば
+					// このプラットフォームで利用可能な収集項目として、Setに追加する
 					if(categoryMap.get(codeBean.getCategoryCode()) != null &&
-							categoryMap.get(codeBean.getCategoryCode()).equals(calcBean.getCollectMethod())) {
+							categoryMap.get(codeBean.getCategoryCode()).equals(calcBean.getId().getCollectMethod())) {
 						// 収集項目コードマスタ情報のDTOを作成
 						CollectorItemCodeMstData codeData = new CollectorItemCodeMstData(
 								codeBean.getItemCode(),
@@ -344,38 +338,38 @@ public class CollectorItemCodeTable {
 								codeBean.getDeviceSupport(),
 								codeBean.getDeviceType(),
 								codeBean.getGraphRange()
-						);
-						m_log.debug("getEnableCodeSet() add itemCode = " + calcBean.getItemCode());
-						tmpByPlatform.add(codeData);
+								);
+						m_log.debug("getEnableCodeSet() add itemCode = " + calcBean.getId().getItemCode());
+						enableItemCodeSetByPlatform.add(codeData);
 					}
 
 				}
-				// プラットフォームごとに収集可能な項目をANDもしくはOR条件でセットに格納する
-				// 同じものだけ追加する(AND条件)
-				if(codeSet == null){
-					m_log.debug("getEnableCodeSet() codeSet is null");
-					codeSet = tmpByPlatform;
-					m_log.debug("getEnableCodeSet() codeSet size = " + codeSet.size());
-				} else {
-					m_log.debug("getEnableCodeSet() codeSet is not null");
-					codeSet.retainAll(tmpByPlatform);
-					m_log.debug("getEnableCodeSet() codeSet size = " + codeSet.size());
+				// 各プラットフォームで出した収集可能項目について、全てのプラットフォームを通じてANDをとる
+				// プラットフォームに関するループ初回で取得した収集可能項目（厳密にはループ中で初めて取得できた
+				// 収集可能項目）は一旦無条件に結果として格納し、以降のプラットフォームで取れる収集可能項目は
+				// その結果に対してANDをとる（set.retainAll）
+				// （つまり重複した部分のみを残して、重ならない部分はこそぎ落としていく）
+				if(enableItemCodeSetInEveryNode == null){
+					m_log.debug("getEnableCodeSet() enableCodeSetInEveryNode is null");
+					enableItemCodeSetInEveryNode = enableItemCodeSetByPlatform;
 				}
+				enableItemCodeSetInEveryNode.retainAll(enableItemCodeSetByPlatform);
+				m_log.debug("getEnableCodeSet() enableCodeSetInEveryNode size = " + enableItemCodeSetInEveryNode.size());
 			}
 
 		} catch (FacilityNotFound e) {
-			m_log.error("getEnableCodeSet() facility not found. (facilityId = " + facilityId + ")", e);
-		} catch (CreateException e) {
-			throw new EJBException(e);
-		} catch (NamingException e) {
-			throw new EJBException(e);
+		} catch (HinemosUnknown e) {
+		} catch (Exception e) {
+			m_log.warn("getEnableCodeSet() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
 
 		// 1つもない場合は、0サイズのSetを返却
-		if(codeSet == null){
-			codeSet = new HashSet<CollectorItemCodeMstData>();
+		if(enableItemCodeSetInEveryNode == null){
+			enableItemCodeSetInEveryNode = new HashSet<CollectorItemCodeMstData>();
 		}
-		return codeSet;
+		return enableItemCodeSetInEveryNode;
 	}
 
 	/**
@@ -383,8 +377,9 @@ public class CollectorItemCodeTable {
 	 * 
 	 * @param facilityId
 	 * @return
+	 * @throws HinemosUnknown
 	 */
-	public static List<CollectorItemInfo> getAvailableCollectorItemList(String facilityId) {
+	public static List<CollectorItemInfo> getAvailableCollectorItemList(String facilityId) throws HinemosUnknown {
 		m_log.debug("getAvailableCollectorItemList() facilityId = " + facilityId);
 
 		// null check
@@ -472,7 +467,7 @@ public class CollectorItemCodeTable {
 
 		// 対象のファシリティIDリスト
 		// targetFacilityIdListはノードのみ含まれる。
-		List<String> targetFacilityIdList = FacilitySelector.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL, false, true);
+		List<String> targetFacilityIdList = FacilitySelector.getNodeFacilityIdList(facilityId, null, RepositoryControllerBean.ALL, false, true);
 		List<NodeDeviceInfo> checkTargetList = null;
 		for (String targetFacilityId : targetFacilityIdList){
 
@@ -487,7 +482,6 @@ public class CollectorItemCodeTable {
 				checkList.addAll(node.getNodeDiskInfo());
 				checkList.addAll(node.getNodeFilesystemInfo());
 			} catch (FacilityNotFound e) {
-				m_log.warn("FacilityNotFound " + e.getMessage());
 			}
 
 			// 1ノード目は全部セット
@@ -522,7 +516,7 @@ public class CollectorItemCodeTable {
 		return deviceSet;
 	}
 
-	
+
 	/**
 	 * 収集項目コードとリポジトリ表示名から収集項目表示用文字列を生成し返します。
 	 * 形式 ：　収集名[リポジトリ表示名]
@@ -543,10 +537,9 @@ public class CollectorItemCodeTable {
 
 			m_log.debug("getFullItemName() itemCode = " + itemCode + ", displayName = " + displayName + " : itemName = " + itemName);
 			return itemName;
-		} catch (FinderException e) {
-			m_log.error("getFullItemName()", e);
-		} catch (NamingException e) {
-			m_log.error("getFullItemName()", e);
+		} catch (Exception e) {
+			m_log.warn("getFullItemName() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 
 		m_log.debug("getFullItemName() itemCode = " + itemCode + ", displayName = " + displayName + " : itemName = " + itemCode + " is not found.");
