@@ -34,10 +34,12 @@ public class ProcessProperties {
 	private static final String START_SECOND = "10";
 	private static final String VALID_SECOND = "15";
 	private static final String DETAILED_DISPLAY = "false";
+	private static final String COLLECT_INITDELAY_SECOND = "60";
 
 	private static final String START_SECOND_KEY = "monitor.process.start.second";
 	private static final String VALID_SECOND_KEY = "monitor.process.valid.second";
 	private static final String DETAILED_DISPLAY_KEY = "monitor.process.details.display";
+	private static final String COLLECT_INITDELAY_SECOND_KEY = "monitor.process.collect.initdelay.second";
 
 	private static ProcessProperties m_instance = null;
 
@@ -47,6 +49,8 @@ public class ProcessProperties {
 	private int m_validSecond;
 	/** オリジナルメッセージにプロセスを表示させるかのフラグ */
 	private boolean m_detailedDisplay;
+	/** マネージャ起動直後の閾値判定処理の遅延時間（秒） */
+	private int m_collectInitDelaySecond;
 
 	/**
 	 * このオブジェクトを取得します。
@@ -94,6 +98,7 @@ public class ProcessProperties {
 			String startSecond = properties.getProperty(START_SECOND_KEY, START_SECOND);
 			String validSecond = properties.getProperty(VALID_SECOND_KEY, VALID_SECOND);
 			String detailedDisplay = properties.getProperty(DETAILED_DISPLAY_KEY, DETAILED_DISPLAY);
+			String collectInitDelaySecond = properties.getProperty(COLLECT_INITDELAY_SECOND_KEY, COLLECT_INITDELAY_SECOND);
 
 			if(startSecond != null && !startSecond.equals(""))
 				m_startSecond = new Integer(startSecond).intValue();
@@ -103,6 +108,9 @@ public class ProcessProperties {
 
 			if(detailedDisplay != null && !detailedDisplay.equals(""))
 				m_detailedDisplay = new Boolean(detailedDisplay).booleanValue();
+			
+			if (collectInitDelaySecond != null && !collectInitDelaySecond.equals(""))
+				m_collectInitDelaySecond = new Integer(collectInitDelaySecond).intValue();
 
 		} catch (Exception e) {
 			m_log.warn("setValue() : "
@@ -130,4 +138,11 @@ public class ProcessProperties {
 	public boolean isDetailedDisplay() {
 		return m_detailedDisplay;
 	}
+	
+	/**
+	 * @return マネージャ起動直後の初回閾値判定処理を行うまでの待ち時間を返します。
+	 */
+	public int getCollectInitDelaySecond() {
+		return m_collectInitDelaySecond;
+	}
 }
