@@ -22,7 +22,7 @@ import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.dialogs.MessageDialog;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.repository.util.NodePropertyUtil;
 import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
 import com.clustercontrol.util.Messages;
@@ -41,24 +41,25 @@ public class GetNodeProperty {
 	// ログ
 	private static Log m_log = LogFactory.getLog( GetNodeProperty.class );
 
-	/**
-	 * ノード属性情報を取得します。
-	 * 
-	 * @param facilityId
-	 * @param property
-	 * @return ノード属性情報
-	 */
-	public Property getProperty(String facilityId, int mode) {
-		Property property = null;
+	// ノード情報
+	private NodeInfo nodeInfo = null;
+
+	// FacilityId
+	private String facilityId = null;
+
+	// mode
+	private int mode;
+
+	public GetNodeProperty(String facilityId, int mode) {
+		this.facilityId = facilityId;
+		this.mode = mode;
 		try {
-			NodeInfo nodeInfo;
-			if (mode == PropertyConstant.MODE_ADD) {
-				nodeInfo = new NodeInfo();
-				NodePropertyUtil.setDefaultNode(nodeInfo);
+			if (this.facilityId == null || this.facilityId.length() == 0) {
+				this.nodeInfo = new NodeInfo();
+				NodePropertyUtil.setDefaultNode(this.nodeInfo);
 			} else {
-				nodeInfo = RepositoryEndpointWrapper.getNode(facilityId);
+				this.nodeInfo = RepositoryEndpointWrapper.getNode(this.facilityId);
 			}
-			property = NodePropertyUtil.node2property(nodeInfo, mode, Locale.getDefault());
 		} catch (InvalidRole_Exception e) {
 			// アクセス権なしの場合、エラーダイアログを表示する
 			MessageDialog.openInformation(null, Messages.getString("message"),
@@ -76,6 +77,23 @@ public class GetNodeProperty {
 					Messages.getString("failed"),
 					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
 		}
-		return property;
+	}
+
+	/**
+	 * ノード属性情報を取得します。
+	 * 
+	 * @return ノード属性情報
+	 */
+	public Property getProperty() {
+		return NodePropertyUtil.node2property(this.nodeInfo, this.mode, Locale.getDefault());
+	}
+
+	/**
+	 * ノード情報を取得します。
+	 * 
+	 * @return ノード情報
+	 */
+	public NodeInfo getNodeInfo() {
+		return this.nodeInfo;
 	}
 }
\ No newline at end of file
