@@ -33,11 +33,13 @@ import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
+import com.clustercontrol.accesscontrol.util.LocalSession;
 import com.clustercontrol.action.FacilityTree;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
-import com.clustercontrol.composite.PropertySheet;
+import com.clustercontrol.composite.RoleIdListComposite;
+import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.repository.bean.ScopeConstant;
@@ -45,6 +47,7 @@ import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
 import com.clustercontrol.repository.util.ScopePropertyUtil;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 import com.clustercontrol.ws.repository.FacilityDuplicate_Exception;
 import com.clustercontrol.ws.repository.InvalidRole_Exception;
 import com.clustercontrol.ws.repository.ScopeInfo;
@@ -77,6 +80,9 @@ public class ScopeCreateDialog extends CommonDialog {
 	/** ノード属性テーブル **/
 	private TableTree table = null;
 
+	/** オーナーロールID用テキスト */
+	private RoleIdListComposite m_ownerRoleId = null;
+
 	// ----- コンストラクタ ----- //
 
 	/**
@@ -128,14 +134,35 @@ public class ScopeCreateDialog extends CommonDialog {
 		layout.marginWidth = 10;
 		layout.marginHeight = 10;
 		parent.setLayout(layout);
-
+		GridData gridData = new GridData();
+		
+		/*
+		 * オーナーロールID
+		 */
+		Label labelRoleId = new Label(parent, SWT.LEFT);
+		gridData = new GridData();
+		gridData.horizontalSpan = 1;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		labelRoleId.setLayoutData(gridData);
+		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
+		if(!this.isModifyDialog()){
+			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, true, Mode.OWNER_ROLE);
+		} else {
+			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, false, Mode.OWNER_ROLE);
+		}
+		gridData = new GridData();
+		gridData.horizontalSpan = 1;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		m_ownerRoleId.setLayoutData(gridData);
+		
+		
 		/*
 		 * 属性プロパティシート
 		 */
-
 		// ラベル
 		Label label = new Label(parent, SWT.LEFT);
-		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.horizontalSpan = 1;
@@ -165,9 +192,43 @@ public class ScopeCreateDialog extends CommonDialog {
 		// プロパティ取得及び設定
 		Property property = null;
 		if (this.isModifyDialog) {
-			property = getScopeProperty(this.facilityId, PropertyConstant.MODE_MODIFY);
+			try {
+				ScopeInfo scopeInfo = RepositoryEndpointWrapper.getScope(this.facilityId);
+				// オーナーロールID取得
+				if (scopeInfo != null && scopeInfo.getOwnerRoleId() != null) {
+					m_ownerRoleId.setText(scopeInfo.getOwnerRoleId());
+				}
+				property = getScopeProperty(scopeInfo, PropertyDefineConstant.MODE_MODIFY);
+			} catch (InvalidRole_Exception e) {
+				// アクセス権なしの場合、エラーダイアログを表示する
+				MessageDialog.openInformation(null, Messages.getString("message"),
+						Messages.getString("message.accesscontrol.16"));
+			} catch (Exception e) {
+				m_log.warn("getScopeProperty(), " + e.getMessage(), e);
+				MessageDialog.openError(
+						null,
+						Messages.getString("failed"),
+						Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+			}
 		} else {
-			property = getScopeProperty(null, PropertyConstant.MODE_ADD);
+			try {
+				ScopeInfo scopeInfo = RepositoryEndpointWrapper.getScope(null);
+				// オーナーロールID取得
+				if (scopeInfo != null && scopeInfo.getOwnerRoleId() != null) {
+					m_ownerRoleId.setText(scopeInfo.getOwnerRoleId());
+				}
+				property = getScopeProperty(scopeInfo, PropertyDefineConstant.MODE_ADD);
+			} catch (InvalidRole_Exception e) {
+				// アクセス権なしの場合、エラーダイアログを表示する
+				MessageDialog.openInformation(null, Messages.getString("message"),
+						Messages.getString("message.accesscontrol.16"));
+			} catch (Exception e) {
+				m_log.warn("getScopeProperty(), " + e.getMessage(), e);
+				MessageDialog.openError(
+						null,
+						Messages.getString("failed"),
+						Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+			}
 		}
 		this.propertySheet.setInput(property);
 
@@ -240,10 +301,13 @@ public class ScopeCreateDialog extends CommonDialog {
 				// 作成の場合
 				try {
 					ScopeInfo scopeinfo = ScopePropertyUtil.property2scope(copy);
+					if (m_ownerRoleId.getText().length() > 0) {
+						scopeinfo.setOwnerRoleId(m_ownerRoleId.getText());
+					}
 					RepositoryEndpointWrapper.addScope(parentFacilityId, scopeinfo);
 
 					// リポジトリキャッシュの更新
-					FacilityTree.reflesh();
+					LocalSession.doCheck();
 
 					MessageDialog.openInformation(
 							null,
@@ -280,10 +344,13 @@ public class ScopeCreateDialog extends CommonDialog {
 				// 変更の場合
 				try {
 					ScopeInfo scopeInfo = ScopePropertyUtil.property2scope(copy);
+					if (m_ownerRoleId.getText().length() > 0) {
+						scopeInfo.setOwnerRoleId(m_ownerRoleId.getText());
+					}
 					RepositoryEndpointWrapper.modifyScope(scopeInfo);
 
 					// リポジトリキャッシュの更新
-					FacilityTree.reflesh();
+					LocalSession.doCheck();
 
 					MessageDialog.openInformation(
 							null,
@@ -375,23 +442,9 @@ public class ScopeCreateDialog extends CommonDialog {
 	 * @param property
 	 * @return スコープ属性情報
 	 */
-	private static Property getScopeProperty(String facilityId, int mode) {
+	private static Property getScopeProperty(ScopeInfo scopeInfo, int mode) {
 
-		Property property = null;
-		try {
-			ScopeInfo scopeInfo = RepositoryEndpointWrapper.getScope(facilityId);
-			property = ScopePropertyUtil.scope2property(scopeInfo, mode, Locale.getDefault());
-		} catch (InvalidRole_Exception e) {
-			// アクセス権なしの場合、エラーダイアログを表示する
-			MessageDialog.openInformation(null, Messages.getString("message"),
-					Messages.getString("message.accesscontrol.16"));
-		} catch (Exception e) {
-			m_log.warn("getScopeProperty(), " + e.getMessage(), e);
-			MessageDialog.openError(
-					null,
-					Messages.getString("failed"),
-					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
-		}
+		Property property = ScopePropertyUtil.scope2property(scopeInfo, mode, Locale.getDefault());
 		return property;
 	}
 }
\ No newline at end of file
