@@ -28,10 +28,10 @@ import org.eclipse.ui.IWorkbenchPage;
 
 import com.clustercontrol.ClusterControlPlugin;
 import com.clustercontrol.bean.TableColumnInfo;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.repository.composite.NodeAttributeComposite;
 import com.clustercontrol.repository.composite.NodeListComposite;
 import com.clustercontrol.view.CommonViewPart;
+import com.clustercontrol.viewer.CommonTableViewer;
 
 /**
  * ノード属性ビュークラス<BR>
@@ -94,7 +94,7 @@ public class NodeAttributeView extends CommonViewPart {
 	public void update() {
 		IWorkbench workbench = ClusterControlPlugin.getDefault().getWorkbench();
 		IWorkbenchPage page = workbench.getActiveWorkbenchWindow()
-		.getActivePage();
+				.getActivePage();
 
 		NodeListView view = null;
 		if (page != null) {
@@ -109,7 +109,7 @@ public class NodeAttributeView extends CommonViewPart {
 			NodeListComposite composite = view.getComposite();
 			CommonTableViewer viewer = composite.getTableViewer();
 			StructuredSelection selection = (StructuredSelection) viewer
-			.getSelection();
+					.getSelection();
 
 			ArrayList list = (ArrayList) selection.getFirstElement();
 			if (list != null) {
