@@ -22,6 +22,7 @@ import java.util.Set;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.poller.bean.PollerProtocolConstant;
 import com.clustercontrol.poller.impl.SnmpPollerImpl;
 import com.clustercontrol.sharedtable.DataTable;
@@ -133,6 +134,11 @@ public class FileSystemPoller {
 			// 収集されたMIB値の中から「HOST-RESOURCES-MIB::hrStorageDescr」のものを抽出
 			mibValues = dataTable.getValueSetStartWith(getEntryKey(STORAGE_DESCR_OID));
 
+			// snmpdが停止している場合は、mibValuesがnullとなる。
+			if (mibValues == null) {
+				throw new HinemosUnknown("snmpd is not running");
+			}
+
 			// ターゲットのファイルシステムの使用量を取得できるOIDを特定
 			for (TableEntry entry : mibValues) {
 				// 取得したMIBのリストの中からマウントポイントに一致するもの取得する
@@ -160,7 +166,7 @@ public class FileSystemPoller {
 			}
 
 		} catch (Exception e) {
-			if (m_log.isWarnEnabled()) m_log.warn("failure in getting a size of a file system with snmp polling.", e);
+			m_log.warn("failure in getting a size of a file system with snmp polling. " + e.getMessage());
 		}
 
 		// ポーリング結果を取得できなかった場合
