@@ -44,14 +44,14 @@ import org.eclipse.ui.PlatformUI;
 
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.composite.CommonTableViewer;
-import com.clustercontrol.composite.StringVerifyListener;
+import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.snmptrap.action.GetMaster;
 import com.clustercontrol.snmptrap.action.GetOidTableDefine;
 import com.clustercontrol.snmptrap.dialog.SnmpTrapCreateDialog;
 import com.clustercontrol.snmptrap.dialog.SnmpTrapMasterDialog;
 import com.clustercontrol.snmptrap.dialog.SnmpTrapModifyDialog;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.monitor.MonitorTrapValueInfo;
 import com.clustercontrol.ws.monitor.SnmpTrapMasterInfo;
 
@@ -69,6 +69,8 @@ public class OidListComposite extends Composite {
 	public static final int MAX_COLUMN = SnmpTrapCreateDialog.MAX_COLUMN;
 	public static final int WIDTH_TITLE = SnmpTrapCreateDialog.WIDTH_TITLE;
 	public static final int WIDTH_VALUE = SnmpTrapCreateDialog.WIDTH_VALUE;
+	public static final int WIDTH_TITLE_WIDE = SnmpTrapCreateDialog.WIDTH_TITLE_WIDE;
+	public static final int WIDTH_TITLE_SMALL = SnmpTrapCreateDialog.WIDTH_TITLE_SMALL;
 
 	// ----- instance フィールド ----- //
 
@@ -144,7 +146,7 @@ public class OidListComposite extends Composite {
 		this.radioSpecific.setText(Messages.getString("OidListComposite.SpecificOid")); //$NON-NLS-1$
 		//Messages.getString("registration.method.node.base"));
 		GridData gridDataRadio = new GridData();
-		gridDataRadio.horizontalSpan = WIDTH_TITLE;
+		gridDataRadio.horizontalSpan = WIDTH_TITLE_SMALL;
 		gridDataRadio.horizontalAlignment = GridData.FILL;
 		gridDataRadio.grabExcessHorizontalSpace = true;
 		this.radioSpecific.setLayoutData(gridDataRadio);
@@ -152,7 +154,7 @@ public class OidListComposite extends Composite {
 		this.radioAll.setText(Messages.getString("OidListComposite.AllMaterOid")); //$NON-NLS-1$
 		//Messages.getString("registration.method.node.base"));
 		gridDataRadio = new GridData();
-		gridDataRadio.horizontalSpan = WIDTH_TITLE;
+		gridDataRadio.horizontalSpan = WIDTH_TITLE_WIDE;
 		gridDataRadio.horizontalAlignment = GridData.FILL;
 		gridDataRadio.grabExcessHorizontalSpace = true;
 		this.radioAll.setLayoutData(gridDataRadio);
@@ -515,7 +517,7 @@ public class OidListComposite extends Composite {
 		radioAll.setEnabled(enabled);
 		radioUnregistered.setEnabled(enabled);
 	}
-	
+
 	/**
 	 * コンポジットを更新します。
 	 * <p>
@@ -649,13 +651,13 @@ public class OidListComposite extends Composite {
 	 * 
 	 * @return
 	 */
-	protected ArrayList<MonitorTrapValueInfo> getSelectionData() {
+	private ArrayList<MonitorTrapValueInfo> getSelectionData() {
 
 		ArrayList<MonitorTrapValueInfo> data = new ArrayList<MonitorTrapValueInfo>();
 
 		//選択されたアイテムを取得
 		StructuredSelection selection =
-			(StructuredSelection)tableViewer.getSelection();
+				(StructuredSelection)tableViewer.getSelection();
 		List list = selection.toList();
 
 		if (list != null) {
