@@ -38,9 +38,8 @@ import org.eclipse.swt.widgets.Text;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.calendar.composite.CalendarIdListComposite;
-import com.clustercontrol.composite.CommonTableViewer;
-import com.clustercontrol.dialog.ValidateResult;
+import com.clustercontrol.composite.RoleIdListComposite;
+import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.composite.MonitorBasicScopeComposite;
 import com.clustercontrol.monitor.run.composite.MonitorRuleComposite;
@@ -68,8 +67,12 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 	public static final int MAX_COLUMN = 20;
 	public static final int MAX_COLUMN_SMALL = 15;
 	public static final int WIDTH_TITLE = 6;
+	public static final int WIDTH_TITLE_WIDE = 8;
+	public static final int WIDTH_TITLE_SMALL = 4;
 	public static final int WIDTH_VALUE = 2;
 
+	
+
 	// 後でpackするためsizeXはダミーの値。
 	private final int sizeX = 750;
 	private final int sizeY = 760;
@@ -113,13 +116,14 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 	 * 
 	 * @param parent 親のシェルオブジェクト
 	 * @param monitorId 変更する監視項目ID
-	 * @param monitorType 監視判定タイプ
+	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public SnmpTrapCreateDialog(Shell parent, String monitorId) {
+	public SnmpTrapCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
 		super(parent);
 		setShellStyle(getShellStyle() | SWT.RESIZE | SWT.MAX);
 
 		this.monitorId = monitorId;
+		this.updateFlg = updateFlg;
 	}
 
 	// ----- instance メソッド ----- //
@@ -162,13 +166,13 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		// 監視基本情報
 		//SNMPトラップでは未登録ノードからのトラップを受け付けるようにするので、
 		//第３引数をtrueとする。
-		m_monitorBasic = new MonitorBasicScopeComposite(parent, SWT.NONE ,true);
+		m_monitorBasic = new MonitorBasicScopeComposite(parent, SWT.NONE ,true, this);
 		gridData = new GridData();
 		gridData.horizontalSpan =MAX_COLUMN;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		m_monitorBasic.setLayoutData(gridData);
-		
+
 		/*
 		 * 条件グループ
 		 */
@@ -191,10 +195,10 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		m_monitorRule.setLayoutData(gridData);
-		
+
 		// 監視間隔の設定を利用不可とする
 		this.m_monitorRule.setRunIntervalEnabled(false);
-		
+
 		/*
 		 * 監視グループ
 		 */
@@ -230,7 +234,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 				}
 			}
 		});
-		
+
 		/*
 		 * トラップ定義グループ
 		 */
@@ -249,7 +253,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		gridData.grabExcessVerticalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
 		groupCheckRule.setText(Messages.getString("trap.definition"));
-		
+
 		/*
 		 * コミュニティ
 		 */
@@ -349,7 +353,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		// ボタン
 		this.buttonCharsetConvertOn = new Button(groupCharset, SWT.RADIO);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_WIDE;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.buttonCharsetConvertOn.setLayoutData(gridData);
@@ -357,7 +361,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		// テキスト
 		this.textCharsetName = new Text(groupCharset, SWT.BORDER | SWT.LEFT);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_SMALL;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textCharsetName.setLayoutData(gridData);
@@ -451,7 +455,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		//ダイアログのサイズ調整（pack:resize to be its preferred size）
 		shell.pack();
 		shell.setSize(new Point(800, shell.getSize().y));
-		
+
 		// 画面中央に
 		Display display = shell.getDisplay();
 		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
@@ -503,7 +507,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		// 監視基本情報
 		super.setInputData(monitor);
 		this.inputData = monitor;
-		
+
 		TrapCheckInfo checkInfo = monitor.getTrapCheckInfo();
 		if (checkInfo == null) {
 			checkInfo = new TrapCheckInfo();
@@ -661,7 +665,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		MonitorInfo info = this.inputData;
 		if(info != null){
 			String[] args = { info.getMonitorId() };
-			if(this.monitorId == null){
+			if(!this.updateFlg){
 				// 作成の場合
 				try {
 					result = MonitorSettingEndpointWrapper.addMonitor(info);
@@ -732,7 +736,7 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		}
 		return result;
 	}
-	
+
 	/**
 	 * 監視エリアを有効/無効化します。
 	 * 
