@@ -51,7 +51,7 @@ public class SnmpTrapMasterDialog extends CommonDialog {
 	private ArrayList<SnmpTrapMasterInfo> inputData = null;
 
 	/** 入力値の正当性を保持するオブジェクト */
-	private ValidateResult validateResult = null;
+	protected ValidateResult validateResult = null;
 
 	/** マスタテーブル */
 	private MasterListComposite masterListComposite = null;
