@@ -34,6 +34,7 @@ import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
+import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorStringDialog;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
 import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
@@ -431,12 +432,20 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 			winEventInfo.getSource().add(source);
 		}
 
-		for(Integer id : commaSeparatedStringToIntegerList(this.eventId.getText())){
-			winEventInfo.getEventId().add(id);
+		try {
+			for(Integer id : commaSeparatedStringToIntegerList(this.eventId.getText())){
+				winEventInfo.getEventId().add(id);
+			}
+		} catch (HinemosUnknown e) {
+			setValidateResult(Messages.getString("message.hinemos.1"), e.getMessage() + "\n"+Messages.getString("winevent.id"));
 		}
-
-		for(Integer category : commaSeparatedStringToIntegerList(this.category.getText())){
-			winEventInfo.getCategory().add(category);
+		
+		try {
+			for(Integer category : commaSeparatedStringToIntegerList(this.category.getText())){
+				winEventInfo.getCategory().add(category);
+			}
+		} catch (HinemosUnknown e) {
+			setValidateResult(Messages.getString("message.hinemos.1"), e.getMessage() + "\n"+Messages.getString("winevent.category"));
 		}
 
 		if(this.keywords.getText() != null && ! "".equals(this.keywords.getText())) {
@@ -445,6 +454,10 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 			}
 		}
 
+		if(validateResult != null){
+			return null;
+		}
+
 		monitorInfo.setWinEventCheckInfo(winEventInfo);
 
 		// 結果判定の定義
@@ -569,7 +582,7 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		}
 	}
 
-	private static List<Integer> commaSeparatedStringToIntegerList(String string){
+	private static List<Integer> commaSeparatedStringToIntegerList(String string) throws HinemosUnknown {
 		String[] numbers = string.split("\\s*,\\s*");
 		ArrayList<Integer> list = new ArrayList<Integer>();
 		try{
@@ -578,12 +591,8 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 					list.add(Integer.parseInt(numbers[i]));
 				}
 			}
-			return list;
 		} catch (NumberFormatException e){
-			MessageDialog.openInformation(
-					null,
-					Messages.getString("message"),
-					Messages.getString("message.winevent.6"));
+			throw new HinemosUnknown(Messages.getString("message.winevent.6"), e);
 		}
 		return list;
 	}
